@@ -35,6 +35,7 @@ import static org.apache.phoenix.util.TestUtil.ROW9;
 import static org.apache.phoenix.util.TestUtil.TEST_PROPERTIES;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
@@ -52,10 +53,13 @@ import java.sql.Timestamp;
 import java.sql.Types;
 import java.text.Format;
 import java.time.LocalDate;
+import java.time.ZoneOffset;
 import java.util.Calendar;
 import java.util.GregorianCalendar;
 import java.util.Properties;
 import java.util.TimeZone;
+import java.util.List;
+import java.util.Arrays;
 
 import org.apache.commons.lang3.time.FastDateFormat;
 import org.apache.hadoop.hbase.filter.CompareFilter.CompareOp;
@@ -76,8 +80,10 @@ import org.apache.phoenix.util.TestUtil;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
+import org.junit.experimental.categories.Category;
 
 
+@Category(ParallelStatsDisabledTest.class)
 public class DateTimeIT extends ParallelStatsDisabledIT {
     private static final String PRODUCT_METRICS_NAME = "PRODUCT_METRICS";
     private static final Date SPLIT1 = toDate("1970-01-01 01:30:00");
@@ -560,7 +566,7 @@ public class DateTimeIT extends ParallelStatsDisabledIT {
     @Test
     public void testYearFunctionDate() throws SQLException {
 
-        assertEquals(2008, callYearFunction("\"YEAR\"(TO_DATE('2008-01-01', 'yyyy-MM-dd', 'local'))"));
+        assertEquals(2008, callYearFunction("\"YEAR\"(TO_DATE('2008-01-01', 'yyyy-MM-dd'))"));
 
         assertEquals(2004,
             callYearFunction("\"YEAR\"(TO_DATE('2004-12-13 10:13:18', 'yyyy-MM-dd hh:mm:ss'))"));
@@ -1939,6 +1945,212 @@ public class DateTimeIT extends ParallelStatsDisabledIT {
         }
     }
 
+    private String getFormattedDate(List<String> dateList) {
+        return String.join("-", dateList.subList(0, 3)) + " "
+                + String.join(":", dateList.subList(3, 6)) + "." + dateList.get(6);
+    }
+
+    @Test
+    public void testAncientDates() throws Exception {
+        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
+        Connection conn = DriverManager.getConnection(url, props);
+        Statement stmt = conn.createStatement();
+        String tableName = generateUniqueName();
+
+        List<String> date1list = Arrays.asList("0010", "10", "10", "10", "10", "10", "111");
+        List<String> date2list = Arrays.asList("1001", "02", "03", "04", "05", "06", "000");
+        List<String> date3list = Arrays.asList("0001", "12", "31", "23", "59", "59", "000");
+        List<List<String>> dateLists = Arrays.asList(date1list, date2list, date3list, date2list);
+
+        String date1 = getFormattedDate(date1list); // 0010-10-10 10:10:10.111
+        String date2 = getFormattedDate(date2list); // 1000-02-03 04:05:06.000
+        String date3 = getFormattedDate(date3list); // 0001-12-31 23:59:59.000
+        List<String> dates = Arrays.asList(date1, date2, date3, date2);
+
+
+        stmt.execute("CREATE TABLE " + tableName + " ( id INTEGER not null PRIMARY KEY," +
+                " date DATE, time TIME, timestamp TIMESTAMP)");
+
+        stmt.execute("UPSERT INTO " + tableName + " VALUES(1, TO_DATE('" + date1
+                + "'), TO_TIME('" + date1 + "'), TO_TIMESTAMP('" + date1 + "'))");
+
+        PreparedStatement pstmt = conn.prepareStatement("UPSERT INTO " + tableName + " values (?, ?, ?, ?)");
+        pstmt.setInt(1, 2);
+        Timestamp t = new Timestamp(DateUtil.parseDate(date2).getTime());
+        pstmt.setDate(2, new Date(t.getTime()));
+        pstmt.setTime(3, new Time(t.getTime()));
+        pstmt.setTimestamp(4, t);
+        pstmt.execute();
+
+        pstmt.setInt(1, 3);
+        t = new Timestamp(DateUtil.parseDate(date3).getTime());
+        pstmt.setDate(2, new Date(t.getTime()));
+        pstmt.setTime(3, new Time(t.getTime()));
+        pstmt.setTimestamp(4, t);
+        pstmt.execute();
+
+        String f = " GMT', 'yyyy-MM-dd HH:mm:ss.SSS z', 'UTC";
+        stmt.execute("UPSERT INTO " + tableName + " VALUES(4, TO_DATE('" + date2 + f
+                + "'), TO_TIME('" + date2 + f + "'), TO_TIMESTAMP('" + date2 + f + "'))");
+        conn.commit();
+
+        ResultSet rs = stmt.executeQuery("SELECT * FROM " + tableName + " ORDER BY id");
+
+        for (int i = 0; i < dates.size(); i++) {
+            assertTrue(rs.next());
+            String actualDate = dates.get(i);
+            Timestamp expectedTimestamp = DateUtil.parseTimestamp(actualDate);
+
+            assertEquals(i + 1, rs.getInt(1));
+            Date expectedDate = new Date(expectedTimestamp.getTime());
+            assertEquals(expectedDate, rs.getDate(2));
+            assertEquals(rs.getDate(2), rs.getObject(2));
+            assertEquals(actualDate, rs.getString(2));
+
+            Time expectedTime = new Time(expectedTimestamp.getTime());
+            assertEquals(new Timestamp(expectedTime.getTime()), new Timestamp(rs.getTime(3).getTime()));
+            assertEquals(expectedTime, rs.getTime(3));
+            assertEquals(rs.getTime(3), rs.getObject(3));
+            assertEquals(actualDate, rs.getString(3));
+
+            assertEquals(expectedTimestamp, rs.getTimestamp(4));
+            assertEquals(rs.getTimestamp(4), rs.getObject(4));
+            assertEquals(actualDate, rs.getString(4));
+        }
+
+        String query = "SELECT year(timestamp), month(timestamp), dayofmonth(timestamp),"
+                + " hour(timestamp), minute(timestamp), second(timestamp) FROM " + tableName
+                + " ORDER BY id";
+        rs = stmt.executeQuery(query);
+
+        for (int i = 0; i < dates.size(); i++) {
+            assertTrue(rs.next());
+            List<String> dateList = dateLists.get(i);
+            for (int j = 0; j < 6; j++) {
+                int expected = Integer.parseInt(dateList.get(j));
+                int value = rs.getInt(j + 1);
+                String readFunc = query.split("\\s+")[j + 1];
+                assertTrue("Expected for " + readFunc.substring(0, readFunc.length() - 1) + ": " + expected + ", got: " + value,
+                        expected == value);
+            }
+        }
+
+        pstmt = conn.prepareStatement("UPSERT INTO " + tableName + " values (?, ?, ?, ?)");
+        pstmt.setInt(1, 5);
+        long l = -123456789100000L;
+        Timestamp inserted = new Timestamp(l);
+        pstmt.setDate(2, new Date(inserted.getTime()));
+        pstmt.setTime(3, new Time(inserted.getTime()));
+        pstmt.setTimestamp(4, inserted);
+        pstmt.execute();
+        conn.commit();
+
+        rs = stmt.executeQuery("SELECT * FROM " + tableName + " WHERE id=5 ORDER BY id");
+        assertTrue(rs.next());
+        Timestamp read = rs.getTimestamp(4);
+        assertEquals(inserted, read);
+    }
+
+    @Test
+    public void testAncientDatesWithJavaTime() throws Exception {
+        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
+        Connection conn = DriverManager.getConnection(url, props);
+        Statement stmt = conn.createStatement();
+        String tableName = generateUniqueName();
+
+        stmt.execute("CREATE TABLE " + tableName + " ( id INTEGER not null PRIMARY KEY," +
+                "timestamp TIMESTAMP)");
+
+        String date = "0010-10-10T10:10:10.111Z";
+
+        java.time.Instant instant = java.time.Instant.parse(date);
+        // 0010-10-10T10:10:10.111Z parsed in ISO chronology
+
+        PreparedStatement pstmt = conn.prepareStatement("UPSERT INTO " + tableName + " values (?, ?)");
+        pstmt.setInt(1, 1);
+        Timestamp inserted = new Timestamp(instant.toEpochMilli());
+        // java.sql.timestamp value will be 0010-10-12 because of GJ chronology used by java.sql.timestamp
+
+        pstmt.setTimestamp(2, inserted);
+        pstmt.execute();
+        conn.commit();
+
+        ResultSet rs = stmt.executeQuery("SELECT * FROM " + tableName + " WHERE id=1");
+        assertTrue(rs.next());
+        Timestamp read = rs.getTimestamp(2); // read back the 0010-10-12 in GJ
+        assertEquals(inserted, read);
+        // java.time.Instant value will be 0010-10-10 in ISO
+        assertEquals(instant, java.time.Instant.ofEpochMilli(read.getTime()));
+
+        assertEquals(instant.toEpochMilli(), read.getTime());
+        // same long value interpreted in different chronology results different date.
+        // Note that the string output is inconsistent but it is expected because of the different chronologies
+        assertEquals(read.toString().split("\\s+")[0], "0010-10-12");
+        assertEquals(instant.toString().split("T")[0], "0010-10-10");
+
+        // test for getdayofMonth will be broken see below because we stored the 0010-10-12 data
+
+        java.time.LocalDateTime localDateTime = java.time.LocalDateTime.of(10, 10, 10, 10, 10, 10);
+        pstmt.setInt(1, 2);
+        inserted = java.sql.Timestamp.valueOf(localDateTime);
+
+        pstmt.setTimestamp(2, inserted);
+        pstmt.execute();
+        conn.commit();
+
+        rs = stmt.executeQuery("SELECT * FROM " + tableName + " WHERE id=2");
+        assertTrue(rs.next());
+        read = rs.getTimestamp(2);
+        assertEquals(inserted, read);
+        assertEquals(localDateTime, read.toLocalDateTime());
+        assertEquals(localDateTime.toEpochSecond(ZoneOffset.UTC),
+                read.toLocalDateTime().toEpochSecond(ZoneOffset.UTC));
+
+        // Inserting via java.sql.Timestamp.valueOf(localDateTime) will result the same toString result
+
+        assertEquals(read.toString().split("\\s+")[0], "0010-10-10");
+        assertEquals(instant.toString().split("T")[0], "0010-10-10");
+
+        // the long value that represents the the Date will be different thought
+        // can be expected because it resulted the same output string using different chronology
+        assertNotEquals(instant.toEpochMilli(), read.getTime());
+
+        // Converting Instant to LocalDateTime will behave like the LocalDateTime example
+        pstmt.setInt(1, 3);
+        java.time.LocalDateTime localDateTime1 = java.time.LocalDateTime.ofInstant(instant, java.time.ZoneId.of("GMT"));
+        inserted = java.sql.Timestamp.valueOf(localDateTime1);
+
+        pstmt.setTimestamp(2, inserted);
+        pstmt.execute();
+        conn.commit();
+
+        rs = stmt.executeQuery("SELECT * FROM " + tableName + " WHERE id=3");
+        assertTrue(rs.next());
+        read = rs.getTimestamp(2);
+        assertEquals(inserted, read);
+        assertEquals(localDateTime1, read.toLocalDateTime());
+        assertEquals(read.toString().split("\\s+")[0], "0010-10-10");
+        assertEquals(localDateTime1.toString().split("T")[0], "0010-10-10");
+
+        java.time.Instant inst = localDateTime1.toInstant(ZoneOffset.UTC);
+        assertEquals(instant, inst);
+        assertNotEquals(inst.toEpochMilli(), inserted.getTime());
+
+
+        String query = "SELECT dayofmonth(timestamp) FROM " + tableName;
+        rs = stmt.executeQuery(query);
+        assertTrue(rs.next());
+        // Timestamp inserted = new Timestamp(instant.toEpochMilli());
+        assertEquals(12, rs.getInt(1));
+        assertTrue(rs.next());
+        // inserted = java.sql.Timestamp.valueOf(localDateTime);
+        assertEquals(10, rs.getInt(1));
+        assertTrue(rs.next());
+        // inserted = java.sql.Timestamp.valueOf(java.time.LocalDateTime.ofInstant(instant, java.time.ZoneId.of("GMT")));
+        assertEquals(10, rs.getInt(1));
+        assertFalse(rs.next());
+    }
+
     public void testDateFormatTimeZone(String timeZoneId) throws Exception {
         Properties props = new Properties();
         props.setProperty("phoenix.query.dateFormatTimeZone", timeZoneId);
