@@ -29,9 +29,11 @@ import org.apache.hadoop.hbase.client.ResultScanner;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.mapreduce.Counter;
 import org.apache.hadoop.mapreduce.CounterGroup;
 import org.apache.phoenix.compat.hbase.HbaseCompatCapabilities;
 import org.apache.phoenix.compat.hbase.coprocessor.CompatBaseScannerRegionObserver;
+import org.apache.phoenix.coprocessor.GlobalIndexRegionScanner;
 import org.apache.phoenix.coprocessor.IndexRepairRegionScanner;
 import org.apache.phoenix.hbase.index.IndexRegionObserver;
 import org.apache.phoenix.index.IndexMaintainer;
@@ -61,6 +63,8 @@ import org.junit.experimental.categories.Category;
 import org.junit.rules.ExpectedException;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import java.io.IOException;
 import java.sql.Connection;
@@ -73,7 +77,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 
-import static org.apache.phoenix.hbase.index.IndexRegionObserver.VERIFIED_BYTES;
 import static org.apache.phoenix.mapreduce.index.IndexVerificationResultRepository.RESULT_TABLE_NAME;
 import static org.apache.phoenix.mapreduce.index.PhoenixIndexToolJobCounters.AFTER_REPAIR_EXTRA_UNVERIFIED_INDEX_ROW_COUNT;
 import static org.apache.phoenix.mapreduce.index.PhoenixIndexToolJobCounters.AFTER_REPAIR_EXTRA_VERIFIED_INDEX_ROW_COUNT;
@@ -83,6 +86,7 @@ import static org.apache.phoenix.mapreduce.index.PhoenixIndexToolJobCounters.BEF
 import static org.apache.phoenix.mapreduce.index.PhoenixIndexToolJobCounters.BEFORE_REPAIR_EXTRA_UNVERIFIED_INDEX_ROW_COUNT;
 import static org.apache.phoenix.mapreduce.index.PhoenixIndexToolJobCounters.BEFORE_REPAIR_EXTRA_VERIFIED_INDEX_ROW_COUNT;
 import static org.apache.phoenix.mapreduce.index.PhoenixIndexToolJobCounters.SCANNED_DATA_ROW_COUNT;
+import static org.apache.phoenix.query.QueryConstants.VERIFIED_BYTES;
 import static org.apache.phoenix.util.TestUtil.TEST_PROPERTIES;
 import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
@@ -96,6 +100,7 @@ import static org.junit.Assume.assumeTrue;
 @RunWith(Parameterized.class)
 public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
 
+    private static final Logger LOGGER = LoggerFactory.getLogger(IndexRepairRegionScannerIT.class);
     private final String tableDDLOptions;
     private final String indexDDLOptions;
     private boolean mutable;
@@ -133,9 +138,11 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
     @BeforeClass
     public static synchronized void doSetup() throws Exception {
         // below settings are needed to enforce major compaction
-        Map<String, String> props = Maps.newHashMapWithExpectedSize(2);
+        Map<String, String> props = Maps.newHashMapWithExpectedSize(3);
         props.put(CompatBaseScannerRegionObserver.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY, Integer.toString(0));
         props.put(QueryServices.GLOBAL_INDEX_ROW_AGE_THRESHOLD_TO_DELETE_MS_ATTRIB, Long.toString(0));
+        // to force multiple verification tasks to be spawned so that we can exercise the page splitting logic
+        props.put(GlobalIndexRegionScanner.INDEX_VERIFY_ROW_COUNTS_PER_TASK_CONF_KEY, Long.toString(2));
         setUpTestDriver(new ReadOnlyProps(props.entrySet().iterator()));
     }
 
@@ -224,6 +231,13 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
         getUtility().getHBaseAdmin().truncateTable(TableName.valueOf(RESULT_TABLE_NAME), true);
     }
 
+    private void dumpIndexToolMRJobCounters(IndexTool indexTool) throws IOException {
+        CounterGroup mrJobCounters = IndexToolIT.getMRJobCounters(indexTool);
+        for (Counter counter : mrJobCounters) {
+            LOGGER.info(String.format("%s=%d", counter.getName(), counter.getValue()));
+        }
+    }
+
     private void assertExtraCounters(IndexTool indexTool, long extraVerified, long extraUnverified,
             boolean isBefore) throws IOException {
         CounterGroup mrJobCounters = IndexToolIT.getMRJobCounters(indexTool);
@@ -241,7 +255,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
         }
     }
 
-    private void assertDisableLogging(Connection conn, int expectedRows,
+    private void assertDisableLogging(Connection conn, int expectedExtraRows, int expectedPITRows,
         IndexTool.IndexVerifyType verifyType,
         IndexTool.IndexDisableLoggingType disableLoggingType,
         byte[] expectedPhase,
@@ -249,24 +263,37 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
         String indexTableName, String indexTableFullName,
         int expectedStatus) throws Exception {
 
-        IndexTool tool = IndexToolIT.runIndexTool(getUtility().getConfiguration(), true, false, schemaName, dataTableName,
+        IndexTool tool = IndexToolIT.runIndexTool(getUtility().getConfiguration(), false, schemaName, dataTableName,
             indexTableName,
             null,
             expectedStatus, verifyType, disableLoggingType, "-fi");
         assertNotNull(tool);
-        byte[] indexTableFullNameBytes = Bytes.toBytes(indexTableFullName);
 
+        try {
+            assertExtraCounters(tool, expectedExtraRows, 0, true);
+        } catch (AssertionError e) {
+            dumpIndexToolMRJobCounters(tool);
+            throw e;
+        }
+
+        byte[] indexTableFullNameBytes = Bytes.toBytes(indexTableFullName);
         IndexVerificationOutputRepository outputRepository =
             new IndexVerificationOutputRepository(indexTableFullNameBytes, conn);
         List<IndexVerificationOutputRow> rows =
             outputRepository.getAllOutputRows();
         try {
-            assertEquals(expectedRows, rows.size());
+            if (expectedPITRows == 0) {
+                assertTrue(rows.isEmpty());
+            } else {
+                // https://issues.apache.org/jira/browse/HBASE-17361 HTable#Put() is not threadsafe
+                // in releases < HBase 2.0 so occasionally we may fail to add some rows to PIT table
+                assertTrue(expectedPITRows >= rows.size());
+            }
         } catch (AssertionError e) {
             TestUtil.dumpTable(conn, TableName.valueOf(IndexVerificationOutputRepository.OUTPUT_TABLE_NAME));
             throw e;
         }
-        if (expectedRows > 0) {
+        if (expectedPITRows > 0) {
             assertArrayEquals(expectedPhase, rows.get(0).getPhaseValue());
         }
     }
@@ -301,7 +328,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
             initTablesAndAddExtraRowsToIndex(conn, schemaName, dataTableName, indexTableName, NROWS);
 
             // do index rebuild without -fi and check with scrutiny that index tool failed to fix the extra rows
-            IndexToolIT.runIndexTool(false, false, schemaName, dataTableName,
+            IndexToolIT.runIndexTool(false, schemaName, dataTableName,
                 indexTableName, null, 0, IndexVerifyType.BEFORE);
 
             boolean failed;
@@ -314,7 +341,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
             assertTrue(failed);
 
             // now repair the index with -fi
-            IndexTool indexTool = IndexToolIT.runIndexTool(false, false, schemaName, dataTableName,
+            IndexTool indexTool = IndexToolIT.runIndexTool(false, schemaName, dataTableName,
                 indexTableName, null, 0, IndexVerifyType.BEFORE, "-fi");
 
             long actualRowCount = IndexScrutiny.scrutinizeIndex(conn, dataTableFullName, indexTableFullName);
@@ -358,7 +385,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
             conn.commit();
             IndexRegionObserver.setFailPostIndexUpdatesForTesting(false);
 
-            IndexTool indexTool = IndexToolIT.runIndexTool(false, false, schemaName, dataTableName,
+            IndexTool indexTool = IndexToolIT.runIndexTool(false, schemaName, dataTableName,
                 indexTableName, null, 0, IndexVerifyType.BEFORE, "-fi");
 
             CounterGroup mrJobCounters = IndexToolIT.getMRJobCounters(indexTool);
@@ -372,7 +399,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
             assertEquals(0,
                 mrJobCounters.findCounter(BEFORE_REPAIR_EXTRA_UNVERIFIED_INDEX_ROW_COUNT.name()).getValue());
 
-            indexTool = IndexToolIT.runIndexTool(false, false, schemaName, dataTableName,
+            indexTool = IndexToolIT.runIndexTool(false, schemaName, dataTableName,
                 indexTableName, null, 0, IndexVerifyType.ONLY, "-fi");
             mrJobCounters = IndexToolIT.getMRJobCounters(indexTool);
             assertEquals(0,
@@ -424,7 +451,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
             IndexRegionObserver.setFailPostIndexUpdatesForTesting(false);
             TestUtil.doMajorCompaction(conn, dataTableFullName);
 
-            IndexTool indexTool = IndexToolIT.runIndexTool(false, false, schemaName, dataTableName,
+            IndexTool indexTool = IndexToolIT.runIndexTool(false, schemaName, dataTableName,
                 indexTableName, null, 0, IndexVerifyType.BEFORE, "-fi");
 
             CounterGroup mrJobCounters = IndexToolIT.getMRJobCounters(indexTool);
@@ -438,7 +465,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
             assertEquals(1,
                 mrJobCounters.findCounter(BEFORE_REPAIR_EXTRA_UNVERIFIED_INDEX_ROW_COUNT.name()).getValue());
 
-            indexTool = IndexToolIT.runIndexTool(false, false, schemaName, dataTableName,
+            indexTool = IndexToolIT.runIndexTool(false, schemaName, dataTableName,
                 indexTableName, null, 0, IndexVerifyType.ONLY, "-fi");
             mrJobCounters = IndexToolIT.getMRJobCounters(indexTool);
 
@@ -488,7 +515,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
             commitWithException(conn);
             IndexRegionObserver.setFailDataTableUpdatesForTesting(true);
 
-            IndexTool indexTool = IndexToolIT.runIndexTool(false, false, schemaName, dataTableName,
+            IndexTool indexTool = IndexToolIT.runIndexTool(false, schemaName, dataTableName,
                 indexTableName, null, 0, IndexVerifyType.BEFORE, "-fi");
 
             long actualRowCount = IndexScrutiny.scrutinizeIndex(conn, dataTableFullName, indexTableFullName);
@@ -511,7 +538,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
         try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
             initTablesAndAddExtraRowsToIndex(conn, schemaName, dataTableName, indexTableName, NROWS);
 
-            IndexToolIT.runIndexTool(false, false, schemaName, dataTableName,
+            IndexToolIT.runIndexTool(false, schemaName, dataTableName,
                 indexTableName, null, 0, IndexVerifyType.ONLY, "-fi");
 
             Cell cell = IndexToolIT.getErrorMessageFromIndexToolOutputTable(conn, dataTableFullName, indexTableFullName);
@@ -535,7 +562,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
             initTablesAndAddExtraRowsToIndex(conn, schemaName, dataTableName, indexTableName, NROWS);
 
             // Run -v AFTER and check it doesn't fix the extra rows and the job fails
-            IndexTool indexTool = IndexToolIT.runIndexTool(false, false, schemaName, dataTableName,
+            IndexTool indexTool = IndexToolIT.runIndexTool(false, schemaName, dataTableName,
                 indexTableName, null, -1, IndexVerifyType.AFTER, "-fi");
 
             boolean failed;
@@ -564,7 +591,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
         try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
             initTablesAndAddExtraRowsToIndex(conn, schemaName, dataTableName, indexTableName, NROWS);
 
-            IndexTool indexTool = IndexToolIT.runIndexTool(false, false, schemaName, dataTableName,
+            IndexTool indexTool = IndexToolIT.runIndexTool(false, schemaName, dataTableName,
                 indexTableName, null, 0, IndexVerifyType.BOTH, "-fi");
 
             long actualRowCount = IndexScrutiny.scrutinizeIndex(conn, dataTableFullName, indexTableFullName);
@@ -589,7 +616,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
 
             Configuration conf = new Configuration(getUtility().getConfiguration());
             conf.set(QueryServices.INDEX_REBUILD_PAGE_SIZE_IN_ROWS, Long.toString(2));
-            IndexTool indexTool = IndexToolIT.runIndexTool(conf,false, false, schemaName, dataTableName,
+            IndexTool indexTool = IndexToolIT.runIndexTool(conf, false, schemaName, dataTableName,
                 indexTableName, null, 0, IndexVerifyType.BEFORE, IndexDisableLoggingType.NONE,"-fi");
 
             long actualRowCount = IndexScrutiny.scrutinizeIndex(conn, dataTableFullName, indexTableFullName);
@@ -634,11 +661,11 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
             conn.commit();
             setIndexRowStatusesToVerified(conn, viewFullName, indexTableFullName1);
 
-            IndexTool indexTool = IndexToolIT.runIndexTool(false, false, schemaName, viewName,
+            IndexTool indexTool = IndexToolIT.runIndexTool(false, schemaName, viewName,
                 indexTableName1, null, 0, IndexVerifyType.BEFORE, "-fi");
             assertExtraCounters(indexTool, 1, 0, true);
 
-            indexTool = IndexToolIT.runIndexTool(false, false, schemaName, viewName,
+            indexTool = IndexToolIT.runIndexTool(false, schemaName, viewName,
                 indexTableName2, null, 0, IndexVerifyType.BEFORE, "-fi");
             assertExtraCounters(indexTool, 1, 0, true);
 
@@ -693,7 +720,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
             long t1 = customEdge.currentTime();
 
             IndexTool it;
-            it = IndexToolIT.runIndexTool(false, false, schemaName, dataTableName,
+            it = IndexToolIT.runIndexTool(false, schemaName, dataTableName,
                 indexTableName, null, 0, IndexVerifyType.ONLY,
                 "-fi", "-st", String.valueOf(t0), "-et", String.valueOf(t1));
 
@@ -722,7 +749,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
             setIndexRowStatusesToVerified(conn, dataTableFullName, indexTableFullName);
             customEdge.incrementValue(delta);
             long t2 = customEdge.currentTime();
-            it = IndexToolIT.runIndexTool(false, false, schemaName, dataTableName,
+            it = IndexToolIT.runIndexTool(false, schemaName, dataTableName,
                 indexTableName, null, 0, IndexVerifyType.ONLY,
                 "-fi", "-st", String.valueOf(t1), "-et", String.valueOf(t2));
 
@@ -736,7 +763,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
                 mrJobCounters.findCounter(BEFORE_REPAIR_EXTRA_UNVERIFIED_INDEX_ROW_COUNT.name()).getValue());
 
             // now run another verification over the entire window [t0, t2]
-            it = IndexToolIT.runIndexTool(false, false, schemaName, dataTableName,
+            it = IndexToolIT.runIndexTool(false, schemaName, dataTableName,
                 indexTableName, null, 0, IndexVerifyType.ONLY,
                 "-fi", "-st", String.valueOf(t0), "-et", String.valueOf(t2));
 
@@ -798,20 +825,20 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
             // run the index MR job as ONLY so the index doesn't get rebuilt. Should be NROWS number
             // of extra rows. We pass in --disable-logging BEFORE to silence the output logging to
             // PHOENIX_INDEX_TOOL
-            assertDisableLogging(conn, 0, IndexTool.IndexVerifyType.ONLY,
+            assertDisableLogging(conn, NROWS, 0, IndexTool.IndexVerifyType.ONLY,
                 IndexTool.IndexDisableLoggingType.BEFORE, null, schemaName, dataTableName, indexTableName,
                 indexTableFullName, 0);
             truncateIndexToolTables();
 
             // logging to PHOENIX_INDEX_TOOL enabled
-            assertDisableLogging(conn, NROWS, IndexTool.IndexVerifyType.ONLY,
+            assertDisableLogging(conn, NROWS, NROWS, IndexTool.IndexVerifyType.ONLY,
                 IndexTool.IndexDisableLoggingType.NONE,
                 IndexVerificationOutputRepository.PHASE_BEFORE_VALUE,schemaName,
                 dataTableName, indexTableName,
                 indexTableFullName, 0);
             truncateIndexToolTables();
 
-            assertDisableLogging(conn, 0, IndexTool.IndexVerifyType.BEFORE,
+            assertDisableLogging(conn, NROWS, 0, IndexTool.IndexVerifyType.BEFORE,
                 IndexTool.IndexDisableLoggingType.BEFORE,
                 null, schemaName,
                 dataTableName, indexTableName,
