@@ -26,6 +26,7 @@ import java.util.Map;
 
 import org.apache.phoenix.compat.hbase.HbaseCompatCapabilities;
 import org.apache.phoenix.mapreduce.index.IndexTool;
+import org.apache.phoenix.query.BaseTest;
 import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.query.QueryServicesOptions;
 import org.apache.phoenix.util.EnvironmentEdge;
@@ -37,12 +38,13 @@ import org.junit.Assert;
 import org.junit.Assume;
 import org.junit.BeforeClass;
 import org.junit.Test;
-
+import org.junit.experimental.categories.Category;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 
 import static org.junit.Assert.assertFalse;
 
-public class IndexToolTimeRangeIT extends BaseUniqueNamesOwnClusterIT {
+@Category(NeedsOwnMiniClusterTest.class)
+public class IndexToolTimeRangeIT extends BaseTest {
     private static final String
             CREATE_TABLE_DDL = "CREATE TABLE %s (ID INTEGER NOT NULL PRIMARY KEY, "
             + "VAL1 INTEGER, VAL2 INTEGER) COLUMN_ENCODED_BYTES=0";
@@ -193,7 +195,7 @@ public class IndexToolTimeRangeIT extends BaseUniqueNamesOwnClusterIT {
     }
 
     private void runIndexTool(String [] args, int expectedStatus) throws Exception {
-        IndexToolIT.runIndexTool(true, false, schemaName, dataTableName,
+        IndexToolIT.runIndexTool(false, schemaName, dataTableName,
                 indexTableName, null, expectedStatus,
                 IndexTool.IndexVerifyType.NONE, args);
     }
