@@ -20,6 +20,7 @@ package org.apache.phoenix.end2end;
 import org.apache.phoenix.compat.hbase.coprocessor.CompatBaseScannerRegionObserver;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.apache.phoenix.mapreduce.index.IndexTool;
+import org.apache.phoenix.query.BaseTest;
 import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.query.QueryServicesOptions;
 import org.apache.phoenix.util.EnvironmentEdgeManager;
@@ -30,6 +31,7 @@ import org.apache.phoenix.util.SchemaUtil;
 
 import org.junit.BeforeClass;
 import org.junit.Test;
+import org.junit.experimental.categories.Category;
 
 import java.sql.Connection;
 import java.sql.DriverManager;
@@ -45,7 +47,8 @@ import static org.apache.phoenix.mapreduce.index.PhoenixIndexToolJobCounters.BEF
 import static org.apache.phoenix.util.TestUtil.TEST_PROPERTIES;
 import static org.junit.Assert.assertEquals;
 
-public class IndexVerificationOldDesignIT extends  BaseUniqueNamesOwnClusterIT {
+@Category(NeedsOwnMiniClusterTest.class)
+public class IndexVerificationOldDesignIT extends BaseTest {
 
     ManualEnvironmentEdge injectEdge;
 
@@ -86,7 +89,7 @@ public class IndexVerificationOldDesignIT extends  BaseUniqueNamesOwnClusterIT {
 
             upsertValidRows(conn, dataTableFullName);
 
-            IndexTool indexTool = IndexToolIT.runIndexTool(true, false, schemaName, dataTableName, indexTableName,
+            IndexTool indexTool = IndexToolIT.runIndexTool(false, schemaName, dataTableName, indexTableName,
                     null, 0, IndexTool.IndexVerifyType.ONLY);
 
             assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_INVALID_INDEX_ROW_COUNT).getValue());
@@ -95,7 +98,7 @@ public class IndexVerificationOldDesignIT extends  BaseUniqueNamesOwnClusterIT {
 
             conn.createStatement().execute("upsert into " + indexTableFullName + " values ('Phoenix5', 6,'G')");
             conn.commit();
-            indexTool = IndexToolIT.runIndexTool(true, false, schemaName, dataTableName, indexTableName,
+            indexTool = IndexToolIT.runIndexTool(false, schemaName, dataTableName, indexTableName,
                     null, 0, IndexTool.IndexVerifyType.ONLY);
 
             assertEquals(1, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_INVALID_INDEX_ROW_COUNT).getValue());
@@ -106,7 +109,7 @@ public class IndexVerificationOldDesignIT extends  BaseUniqueNamesOwnClusterIT {
             injectEdge.setValue(EnvironmentEdgeManager.currentTimeMillis() + ttl*1000);
             EnvironmentEdgeManager.injectEdge(injectEdge);
 
-            indexTool = IndexToolIT.runIndexTool(true, false, schemaName, dataTableName, indexTableName,
+            indexTool = IndexToolIT.runIndexTool(false, schemaName, dataTableName, indexTableName,
                     null, 0, IndexTool.IndexVerifyType.ONLY);
 
             assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_INVALID_INDEX_ROW_COUNT).getValue());
@@ -138,14 +141,14 @@ public class IndexVerificationOldDesignIT extends  BaseUniqueNamesOwnClusterIT {
 
             upsertValidRows(conn, fullViewName);
 
-            IndexToolIT.runIndexTool(true, false, schemaName, viewName, indexTableName,
+            IndexToolIT.runIndexTool(false, schemaName, viewName, indexTableName,
                     null, 0, IndexTool.IndexVerifyType.ONLY);
 
             conn.createStatement().execute("upsert into " + indexTableFullName + " values ('Phoenix5', 6,'G')");
             conn.createStatement().execute("delete from " + indexTableFullName + " where \"0:CODE\" = 'D'");
             conn.commit();
 
-            IndexTool indexTool = IndexToolIT.runIndexTool(true, false, schemaName, viewName, indexTableName,
+            IndexTool indexTool = IndexToolIT.runIndexTool(false, schemaName, viewName, indexTableName,
                     null, 0, IndexTool.IndexVerifyType.ONLY);
             assertEquals(1, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_INVALID_INDEX_ROW_COUNT).getValue());
             assertEquals(4, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_VALID_INDEX_ROW_COUNT).getValue());
