@@ -17,14 +17,9 @@
  */
 package org.apache.phoenix.end2end;
 
-import java.lang.annotation.ElementType;
-import java.lang.annotation.Retention;
-import java.lang.annotation.RetentionPolicy;
-import java.lang.annotation.Target;
-
 /**
  * 
- * Annotation to denote that the test needs to run its own
+ * Marker class to denote that the test needs to run its own
  * mini cluster that is separate from the clusters used by
  * tests annotated as {@link ParallelStatsDisabledTest} or
  * {@link ParallelStatsEnabledTest}.
@@ -37,8 +32,6 @@ import java.lang.annotation.Target;
  * 
  * @since 4.1
  */
-@Retention(RetentionPolicy.RUNTIME)
-@Target(ElementType.TYPE)
-public @interface NeedsOwnMiniClusterTest {
+public class NeedsOwnMiniClusterTest {
 
 }
