@@ -37,7 +37,9 @@ import org.apache.phoenix.compat.hbase.CompatUtil;
 import org.apache.phoenix.util.SchemaUtil;
 import org.junit.BeforeClass;
 import org.junit.Test;
+import org.junit.experimental.categories.Category;
 
+@Category(NeedsOwnMiniClusterTest.class)
 public class PermissionsCacheIT extends BasePermissionsIT {
 
     public PermissionsCacheIT() throws Exception {
@@ -100,8 +102,6 @@ public class PermissionsCacheIT extends BasePermissionsIT {
         } catch (Exception e) {
             System.out.println("Exception occurred: " + e);
             throw e;
-        } finally {
-            revokeAll();
         }
     }
 
