@@ -33,6 +33,7 @@ import java.sql.ParameterMetaData;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
+import java.sql.Statement;
 import java.util.List;
 import java.util.Properties;
 
@@ -57,10 +58,11 @@ import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
-
+import org.junit.experimental.categories.Category;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 
+@Category(ParallelStatsDisabledTest.class)
 public class SequenceIT extends ParallelStatsDisabledIT {
     private static final String SELECT_NEXT_VALUE_SQL = "SELECT NEXT VALUE FOR %s";
     private static final String SCHEMA_NAME = "S";
@@ -1465,6 +1467,27 @@ public class SequenceIT extends ParallelStatsDisabledIT {
         assertEquals(5, rs.getInt(2));
     }
 
+    @Test
+    public void testBug6574() throws Exception {
+        String sequenceName = generateSequenceNameWithSchema();
+        String tableName = generateTableNameWithSchema();
+
+        try(Statement stmt = conn.createStatement()) {
+            stmt.execute("CREATE SEQUENCE " + sequenceName);
+            stmt.execute("CREATE TABLE " + tableName + " (id integer primary key)");
+
+            String query = "SELECT * FROM SYSTEM.\"SEQUENCE\" where SEQUENCE_NAME = '" + getNameWithoutSchema(sequenceName) + "'";
+            ResultSet rs = stmt.executeQuery(query);
+            assertTrue(rs.next());
+            rs.close();
+
+            stmt.execute("DROP TABLE " + tableName);
+            rs = stmt.executeQuery(query);
+            assertTrue(rs.next());
+            rs.close();
+        }
+    }
+
     private static String getSchemaName(String tableName) {
         return tableName.substring(0, tableName.indexOf("."));
     }
