@@ -47,7 +47,7 @@ import org.apache.phoenix.util.PropertiesUtil;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
-
+import org.junit.experimental.categories.Category;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 /**
@@ -55,6 +55,7 @@ import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
  */
 
 
+@Category(ParallelStatsDisabledTest.class)
 public class SortOrderIT extends ParallelStatsDisabledIT {
     private String baseTableName;
     
