@@ -187,7 +187,7 @@ public class SystemTablesCreationOnConnectionIT {
                 boolean refCountLeaked = false;
                 if (isMasterAvailable) {
                     refCountLeaked = CompatUtil.isAnyStoreRefCountLeaked(
-                            testUtil.getHBaseCluster().getMaster());
+                            testUtil.getAdmin());
                 }
                 testUtil.shutdownMiniCluster();
                 testUtil = null;
@@ -562,7 +562,7 @@ public class SystemTablesCreationOnConnectionIT {
      */
     private Set<String> getHBaseTables() throws IOException {
         Set<String> tables = new HashSet<>();
-        for (TableName tn : testUtil.getHBaseAdmin().listTableNames()) {
+        for (TableName tn : testUtil.getAdmin().listTableNames()) {
             tables.add(tn.getNameAsString());
         }
         return tables;
@@ -571,7 +571,7 @@ public class SystemTablesCreationOnConnectionIT {
     // Check if the SYSTEM namespace has been created
     private boolean isSystemNamespaceCreated() throws IOException {
         try {
-            testUtil.getHBaseAdmin().getNamespaceDescriptor(SYSTEM_CATALOG_SCHEMA);
+            testUtil.getAdmin().getNamespaceDescriptor(SYSTEM_CATALOG_SCHEMA);
         } catch (NamespaceNotFoundException ex) {
             return false;
         }
