@@ -17,6 +17,7 @@
  */
 package org.apache.phoenix.end2end;
 
+import static org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder.KEEP_DELETED_CELLS;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.COLUMN_FAMILY;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.COLUMN_NAME;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.LAST_DDL_TIMESTAMP;
@@ -43,7 +44,9 @@ import java.sql.DriverManager;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
+import java.sql.Statement;
 import java.sql.Types;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Properties;
 import java.util.Set;
@@ -57,12 +60,18 @@ import java.util.concurrent.atomic.AtomicInteger;
 
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellUtil;
+import org.apache.hadoop.hbase.HConstants;
+import org.apache.hadoop.hbase.KeepDeletedCells;
 import org.apache.hadoop.hbase.KeyValue;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptor;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
 import org.apache.hadoop.hbase.client.Put;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.client.Table;
+import org.apache.hadoop.hbase.client.TableDescriptor;
+import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.phoenix.schema.types.PInteger;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Sets;
@@ -74,9 +83,11 @@ import org.apache.phoenix.jdbc.PhoenixDatabaseMetaData;
 import org.apache.phoenix.query.ConnectionQueryServices;
 import org.apache.phoenix.query.ConnectionQueryServicesImpl;
 import org.apache.phoenix.query.DelegateConnectionQueryServices;
+import org.apache.phoenix.query.QueryConstants;
 import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.schema.PName;
 import org.apache.phoenix.schema.PNameFactory;
+import org.apache.phoenix.schema.PTable;
 import org.apache.phoenix.schema.PTable.LinkType;
 import org.apache.phoenix.schema.PTableType;
 import org.apache.phoenix.schema.SequenceAllocation;
@@ -109,8 +120,7 @@ public class UpgradeIT extends ParallelStatsDisabledIT {
                     return true;
                 }
             };
-            try (PhoenixConnection phxConn = new PhoenixConnection(servicesWithUpgrade, getUrl(), PropertiesUtil.deepCopy(TestUtil.TEST_PROPERTIES), 
-                    conn.unwrap(PhoenixConnection.class).getMetaDataCache())) {
+            try (PhoenixConnection phxConn = new PhoenixConnection(servicesWithUpgrade, getUrl(), PropertiesUtil.deepCopy(TestUtil.TEST_PROPERTIES))) {
                 try {
                     phxConn.createStatement().execute(
                             "CREATE TABLE " + generateUniqueName()
@@ -358,6 +368,112 @@ public class UpgradeIT extends ParallelStatsDisabledIT {
         }
     }
 
+    @Test
+    public void testRemoveScnFromTaskAndLog() throws Exception {
+        PhoenixConnection conn = getConnection(false, null).unwrap(PhoenixConnection.class);
+        ConnectionQueryServicesImpl cqs = (ConnectionQueryServicesImpl)(conn.getQueryServices());
+        //Set the SCN related properties on SYSTEM.STATS and SYSTEM.LOG
+        try (Statement stmt = conn.createStatement()) {
+            stmt.executeUpdate("ALTER TABLE " +
+                    PhoenixDatabaseMetaData.SYSTEM_LOG_NAME + " SET " +
+                    KEEP_DELETED_CELLS + "='" + KeepDeletedCells.TRUE + "',\n" +
+                    HConstants.VERSIONS + "='1000'\n");
+            stmt.executeUpdate("ALTER TABLE " +
+                    PhoenixDatabaseMetaData.SYSTEM_STATS_NAME + " SET " +
+                    KEEP_DELETED_CELLS + "='" + KeepDeletedCells.TRUE + "',\n" +
+                    HConstants.VERSIONS + "='1000'\n");
+        }
+        //Check that the HBase tables reflect the change
+        PTable sysLogTable = PhoenixRuntime.getTable(conn, PhoenixDatabaseMetaData.SYSTEM_LOG_NAME);
+        TableDescriptor sysLogDesc = utility.getAdmin().getDescriptor(SchemaUtil.getPhysicalTableName(
+            PhoenixDatabaseMetaData.SYSTEM_LOG_NAME, cqs.getProps()));
+        assertEquals(KeepDeletedCells.TRUE, sysLogDesc.getColumnFamily(
+            SchemaUtil.getEmptyColumnFamily(sysLogTable)).getKeepDeletedCells());
+        assertEquals(1000, sysLogDesc.getColumnFamily(
+                SchemaUtil.getEmptyColumnFamily(sysLogTable)).getMaxVersions());
+
+        PTable sysStatsTable = PhoenixRuntime.getTable(conn, PhoenixDatabaseMetaData.SYSTEM_STATS_NAME);
+        TableDescriptor sysStatsDesc = utility.getAdmin().getDescriptor(SchemaUtil.getPhysicalTableName(
+            PhoenixDatabaseMetaData.SYSTEM_STATS_NAME, cqs.getProps()));
+        assertEquals(KeepDeletedCells.TRUE, sysStatsDesc.getColumnFamily(
+            SchemaUtil.getEmptyColumnFamily(sysStatsTable)).getKeepDeletedCells());
+        assertEquals(1000, sysStatsDesc.getColumnFamily(
+            SchemaUtil.getEmptyColumnFamily(sysStatsTable)).getMaxVersions());
+
+        //now call the upgrade code
+        cqs.upgradeSystemLog(conn, new HashMap<String, String>());
+        cqs.upgradeSystemStats(conn, new HashMap<String, String>());
+
+        //Check that HBase tables are fixed
+        sysLogDesc = utility.getAdmin().getDescriptor(SchemaUtil.getPhysicalTableName(
+            PhoenixDatabaseMetaData.SYSTEM_LOG_NAME, cqs.getProps()));
+        assertEquals(KeepDeletedCells.FALSE, sysLogDesc.getColumnFamily(
+            SchemaUtil.getEmptyColumnFamily(sysLogTable)).getKeepDeletedCells());
+        assertEquals(1, sysLogDesc.getColumnFamily(
+                SchemaUtil.getEmptyColumnFamily(sysLogTable)).getMaxVersions());
+
+        sysStatsDesc = utility.getAdmin().getDescriptor(SchemaUtil.getPhysicalTableName(
+            PhoenixDatabaseMetaData.SYSTEM_STATS_NAME, cqs.getProps()));
+        assertEquals(KeepDeletedCells.FALSE, sysStatsDesc.getColumnFamily(
+            SchemaUtil.getEmptyColumnFamily(sysStatsTable)).getKeepDeletedCells());
+        assertEquals(1, sysStatsDesc.getColumnFamily(
+            SchemaUtil.getEmptyColumnFamily(sysStatsTable)).getMaxVersions());
+    }
+
+    @Test
+    public void testCacheOnWritePropsOnSystemSequence() throws Exception {
+        PhoenixConnection conn = getConnection(false, null).
+            unwrap(PhoenixConnection.class);
+        ConnectionQueryServicesImpl cqs = (ConnectionQueryServicesImpl)(conn.getQueryServices());
+
+        TableDescriptor initialTD = utility.getAdmin().getDescriptor(
+            SchemaUtil.getPhysicalTableName(PhoenixDatabaseMetaData.SYSTEM_SEQUENCE_NAME,
+                cqs.getProps()));
+        ColumnFamilyDescriptor initialCFD = initialTD.getColumnFamily(
+            QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES);
+
+        // Confirm that the Cache-On-Write related properties are set
+        // on SYSTEM.SEQUENCE during creation.
+        assertEquals(Boolean.TRUE, initialCFD.isCacheBloomsOnWrite());
+        assertEquals(Boolean.TRUE, initialCFD.isCacheDataOnWrite());
+        assertEquals(Boolean.TRUE, initialCFD.isCacheIndexesOnWrite());
+
+        // Check to see whether the Cache-On-Write related properties are set on
+        // pre-existing tables too via the upgrade path. We do the below to test it :
+        // 1. Explicitly disable the Cache-On-Write related properties on the table.
+        // 2. Call the Upgrade Path on the table.
+        // 3. Verify that the property is set after the upgrades too.
+        ColumnFamilyDescriptorBuilder newCFBuilder =
+            ColumnFamilyDescriptorBuilder.newBuilder(initialCFD);
+        newCFBuilder.setCacheBloomsOnWrite(false);
+        newCFBuilder.setCacheDataOnWrite(false);
+        newCFBuilder.setCacheIndexesOnWrite(false);
+        TableDescriptorBuilder newTD = TableDescriptorBuilder.newBuilder(initialTD);
+        newTD.modifyColumnFamily(newCFBuilder.build());
+        utility.getAdmin().modifyTable(newTD.build());
+
+        // Check that the Cache-On-Write related properties are now disabled.
+        TableDescriptor updatedTD = utility.getAdmin().getDescriptor(
+            SchemaUtil.getPhysicalTableName(PhoenixDatabaseMetaData.SYSTEM_SEQUENCE_NAME,
+                cqs.getProps()));
+        ColumnFamilyDescriptor updatedCFD = updatedTD.getColumnFamily(
+            QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES);
+        assertEquals(Boolean.FALSE, updatedCFD.isCacheBloomsOnWrite());
+        assertEquals(Boolean.FALSE, updatedCFD.isCacheDataOnWrite());
+        assertEquals(Boolean.FALSE, updatedCFD.isCacheIndexesOnWrite());
+
+        // Let's try upgrading the existing table - and see if the property is set on
+        // during upgrades.
+        cqs.upgradeSystemSequence(conn, new HashMap<String, String>());
+
+        updatedTD = utility.getAdmin().getDescriptor(SchemaUtil.getPhysicalTableName(
+            PhoenixDatabaseMetaData.SYSTEM_SEQUENCE_NAME, cqs.getProps()));
+        updatedCFD = updatedTD.getColumnFamily(QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES);
+        assertEquals(Boolean.TRUE, updatedCFD.isCacheBloomsOnWrite());
+        assertEquals(Boolean.TRUE, updatedCFD.isCacheDataOnWrite());
+        assertEquals(Boolean.TRUE, updatedCFD.isCacheIndexesOnWrite());
+    }
+
     private Set<String> getChildLinks(Connection conn) throws SQLException {
         ResultSet rs =
                 conn.createStatement().executeQuery(
