@@ -47,10 +47,11 @@ import java.util.Properties;
 
 import org.apache.phoenix.thirdparty.com.google.common.base.Strings;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
-import org.apache.phoenix.end2end.BaseUniqueNamesOwnClusterIT;
 import org.apache.phoenix.end2end.IndexToolIT;
+import org.apache.phoenix.end2end.NeedsOwnMiniClusterTest;
 import org.apache.phoenix.hbase.index.IndexRegionObserver;
 import org.apache.phoenix.mapreduce.index.IndexTool;
+import org.apache.phoenix.query.BaseTest;
 import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.schema.PTableImpl;
 import org.apache.phoenix.util.EnvironmentEdgeManager;
@@ -62,13 +63,15 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.BeforeClass;
 import org.junit.Test;
+import org.junit.experimental.categories.Category;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 import org.junit.runners.Parameterized.Parameters;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
+@Category(NeedsOwnMiniClusterTest.class)
 @RunWith(Parameterized.class)
-public class GlobalIndexCheckerIT extends BaseUniqueNamesOwnClusterIT {
+public class GlobalIndexCheckerIT extends BaseTest {
 
     private final boolean async;
     private String indexDDLOptions;
@@ -153,7 +156,7 @@ public class GlobalIndexCheckerIT extends BaseUniqueNamesOwnClusterIT {
                     dataTableName + " (val1) include (val2, val3)" + (async ? "ASYNC" : "") + this.indexDDLOptions);
             if (async) {
                 // run the index MR job.
-                IndexToolIT.runIndexTool(true, false, null, dataTableName, indexTableName);
+                IndexToolIT.runIndexTool(false, null, dataTableName, indexTableName);
             }
             // Count the number of index rows
             String query = "SELECT COUNT(*) from " + indexTableName;
@@ -186,7 +189,7 @@ public class GlobalIndexCheckerIT extends BaseUniqueNamesOwnClusterIT {
                     dataTableName + " (val1, PHOENIX_ROW_TIMESTAMP()) " + "include (val2, val3) " + (async ? "ASYNC" : "")+ this.indexDDLOptions);
             if (async) {
                 // Run the index MR job to rebuild the index and verify that index is built correctly
-                IndexToolIT.runIndexTool(true, false, null, dataTableName,
+                IndexToolIT.runIndexTool(false, null, dataTableName,
                         indexTableName, null, 0, IndexTool.IndexVerifyType.AFTER);
             }
 
@@ -271,7 +274,7 @@ public class GlobalIndexCheckerIT extends BaseUniqueNamesOwnClusterIT {
                     (async ? "ASYNC" : "")+ this.indexDDLOptions);
             if (async) {
                 // Run the index MR job to rebuild the index and verify that index is built correctly
-                IndexToolIT.runIndexTool(true, false, null, dataTableName,
+                IndexToolIT.runIndexTool(false, null, dataTableName,
                         indexTableName, null, 0, IndexTool.IndexVerifyType.AFTER);
             }
             // Add one more row
@@ -301,6 +304,44 @@ public class GlobalIndexCheckerIT extends BaseUniqueNamesOwnClusterIT {
             assertEquals("ae", rs.getString(1));
             assertEquals("efg", rs.getString(2));
             assertFalse(rs.next());
+            conn.createStatement().execute("DROP INDEX " + indexTableName + " on " +
+                    dataTableName);
+            // Run the previous test on an uncovered global index
+            indexTableName = generateUniqueName();
+            conn.createStatement().execute("CREATE INDEX " + indexTableName + " on " +
+                    dataTableName + " (PHOENIX_ROW_TIMESTAMP())" +
+                    (async ? "ASYNC" : "")+ this.indexDDLOptions);
+            if (async) {
+                // Run the index MR job to rebuild the index and verify that index is built correctly
+                IndexToolIT.runIndexTool(false, null, dataTableName,
+                        indexTableName, null, 0, IndexTool.IndexVerifyType.AFTER);
+            }
+            // Verify that without hint, the index table is not selected
+            assertIndexTableNotSelected(conn, dataTableName, indexTableName, query);
+
+            // Verify that we will read from the index table with the index hint
+            query = "SELECT /*+ INDEX(" + dataTableName + " " + indexTableName + ")*/ " +
+                    "val1, val2, PHOENIX_ROW_TIMESTAMP() from " + dataTableName + " WHERE " +
+                    "PHOENIX_ROW_TIMESTAMP() > TO_DATE('" + initial.toString() + "','yyyy-MM-dd HH:mm:ss.SSS', '" + timeZoneID + "')";
+
+            assertExplainPlan(conn, query, dataTableName, indexTableName);
+            rs = conn.createStatement().executeQuery(query);
+            assertTrue(rs.next());
+            assertEquals("ab", rs.getString(1));
+            assertEquals("abc", rs.getString(2));
+            assertTrue(rs.next());
+            assertEquals("bc", rs.getString(1));
+            assertEquals("bcd", rs.getString(2));
+            assertTrue(rs.next());
+            assertEquals("bc", rs.getString(1));
+            assertEquals("ccc", rs.getString(2));
+            assertTrue(rs.next());
+            assertEquals("de", rs.getString(1));
+            assertEquals("def", rs.getString(2));
+            assertTrue(rs.next());
+            assertEquals("ae", rs.getString(1));
+            assertEquals("efg", rs.getString(2));
+            assertFalse(rs.next());
         }
     }
 
@@ -324,7 +365,7 @@ public class GlobalIndexCheckerIT extends BaseUniqueNamesOwnClusterIT {
             conn.createStatement().executeUpdate(dml);
             conn.commit();
             // Make sure this delete attempt did not make the index and data table inconsistent
-            IndexToolIT.runIndexTool(true, false, "", dataTableName, indexTableName, null,
+            IndexToolIT.runIndexTool(false, "", dataTableName, indexTableName, null,
                     0, IndexTool.IndexVerifyType.ONLY);
         }
     }
@@ -425,6 +466,16 @@ public class GlobalIndexCheckerIT extends BaseUniqueNamesOwnClusterIT {
         }
     }
 
+    private void assertIndexTableNotSelected(Connection conn, String dataTableName, String indexTableName, String sql)
+            throws Exception {
+        try {
+            assertExplainPlan(conn, sql, dataTableName, indexTableName);
+            throw new AssertionError("The index table should not be selected without an index hint");
+        } catch (AssertionError error){
+            //expected
+        }
+    }
+
     @Test
     public void testSimulateConcurrentUpdates() throws Exception {
         try (Connection conn = DriverManager.getConnection(getUrl())) {
@@ -435,7 +486,7 @@ public class GlobalIndexCheckerIT extends BaseUniqueNamesOwnClusterIT {
                     dataTableName + " (val1) include (val2, val3)" + (async ? "ASYNC" : "") + this.indexDDLOptions);
             if (async) {
                 // run the index MR job.
-                IndexToolIT.runIndexTool(true, false, null, dataTableName, indexTableName);
+                IndexToolIT.runIndexTool(false, null, dataTableName, indexTableName);
             }
             // For the concurrent updates on the same row, the last write phase is ignored.
             // Configure IndexRegionObserver to fail the last write phase (i.e., the post index update phase) where the
@@ -479,7 +530,7 @@ public class GlobalIndexCheckerIT extends BaseUniqueNamesOwnClusterIT {
                     dataTableName + " (val1) include (val2, val3)" + (async ? "ASYNC" : "") + this.indexDDLOptions);
             if (async) {
                 // run the index MR job.
-                IndexToolIT.runIndexTool(true, false, null, dataTableName, indexTableName);
+                IndexToolIT.runIndexTool(false, null, dataTableName, indexTableName);
             }
             String selectSql = "SELECT id from " + dataTableName + " WHERE val1  = 'ab'";
             ResultSet rs = conn.createStatement().executeQuery(selectSql);
@@ -524,7 +575,7 @@ public class GlobalIndexCheckerIT extends BaseUniqueNamesOwnClusterIT {
                 dataTableName + " (val1) include (val2, val3)" + (async ? "ASYNC" : "") + this.indexDDLOptions);
         if (async) {
             // run the index MR job.
-            IndexToolIT.runIndexTool(true, false, null, dataTableName, indexTableName);
+            IndexToolIT.runIndexTool(false, null, dataTableName, indexTableName);
         }
         conn.createStatement().execute("upsert into " + dataTableName + " (id, val2) values ('a', 'abcc')");
         conn.commit();
@@ -617,7 +668,7 @@ public class GlobalIndexCheckerIT extends BaseUniqueNamesOwnClusterIT {
                     dataTableName + " (val1) include (val2, val3)" + (async ? "ASYNC" : "") + this.indexDDLOptions);
             if (async) {
                 // run the index MR job.
-                IndexToolIT.runIndexTool(true, false, null, dataTableName, indexTableName);
+                IndexToolIT.runIndexTool(false, null, dataTableName, indexTableName);
             }
             // Configure IndexRegionObserver to fail the first write phase (i.e., the pre index update phase). This should not
             // lead to any change on index or data table rows
@@ -650,7 +701,7 @@ public class GlobalIndexCheckerIT extends BaseUniqueNamesOwnClusterIT {
                     dataTableName + " (val1) include (val2, val3)" + (async ? "ASYNC" : "") + this.indexDDLOptions);
             if (async) {
                 // run the index MR job.
-                IndexToolIT.runIndexTool(true, false, null, dataTableName, indexTableName);
+                IndexToolIT.runIndexTool(false, null, dataTableName, indexTableName);
             }
             // Configure IndexRegionObserver to fail the last write phase (i.e., the post index update phase) where the verify flag is set
             // to true and/or index rows are deleted and check that this does not impact the correctness
@@ -659,7 +710,7 @@ public class GlobalIndexCheckerIT extends BaseUniqueNamesOwnClusterIT {
             conn.commit();
             conn.createStatement().execute("upsert into " + dataTableName + " (id, val1, val2) values ('c', 'cd','cde')");
             conn.commit();
-            IndexTool indexTool = IndexToolIT.runIndexTool(true, false, "", dataTableName, indexTableName, null, 0, IndexTool.IndexVerifyType.ONLY);
+            IndexTool indexTool = IndexToolIT.runIndexTool(false, "", dataTableName, indexTableName, null, 0, IndexTool.IndexVerifyType.ONLY);
             assertEquals(3, indexTool.getJob().getCounters().findCounter(INPUT_RECORDS).getValue());
             assertEquals(3, indexTool.getJob().getCounters().findCounter(SCANNED_DATA_ROW_COUNT).getValue());
             assertEquals(0, indexTool.getJob().getCounters().findCounter(REBUILT_INDEX_ROW_COUNT).getValue());
@@ -797,8 +848,8 @@ public class GlobalIndexCheckerIT extends BaseUniqueNamesOwnClusterIT {
                     dataTableName + " (val2) include (val1, val3)" + (async ? "ASYNC" : "") + this.indexDDLOptions);
             if (async) {
                 // run the index MR job.
-                IndexToolIT.runIndexTool(true, false, null, dataTableName, indexTableName + "1");
-                IndexToolIT.runIndexTool(true, false, null, dataTableName, indexTableName + "2");
+                IndexToolIT.runIndexTool(false, null, dataTableName, indexTableName + "1");
+                IndexToolIT.runIndexTool(false, null, dataTableName, indexTableName + "2");
             }
             // Two Phase write. This write is recoverable
             IndexRegionObserver.setFailPostIndexUpdatesForTesting(true);
@@ -917,8 +968,8 @@ public class GlobalIndexCheckerIT extends BaseUniqueNamesOwnClusterIT {
         conn.commit();
         if (async) {
             // run the index MR job.
-            IndexToolIT.runIndexTool(true, false, null, dataTableName, indexTableName + "1");
-            IndexToolIT.runIndexTool(true, false, null, dataTableName, indexTableName + "2");
+            IndexToolIT.runIndexTool(false, null, dataTableName, indexTableName + "1");
+            IndexToolIT.runIndexTool(false, null, dataTableName, indexTableName + "2");
         }
     }
 
