@@ -31,11 +31,12 @@ import org.apache.hadoop.hbase.coprocessor.SimpleRegionObserver;
 import org.apache.hadoop.hbase.regionserver.MiniBatchOperationInProgress;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.end2end.ParallelStatsDisabledIT;
-import org.apache.phoenix.hbase.index.IndexRegionObserver;
+import org.apache.phoenix.end2end.ParallelStatsDisabledTest;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.query.ConnectionQueryServices;
 import org.apache.phoenix.schema.PIndexState;
 import org.apache.phoenix.schema.PTable;
+import org.apache.phoenix.query.QueryConstants;
 import org.apache.phoenix.util.EncodedColumnsUtil;
 import org.apache.phoenix.util.PhoenixRuntime;
 import org.apache.phoenix.util.ReadOnlyProps;
@@ -43,6 +44,7 @@ import org.apache.phoenix.util.SchemaUtil;
 import org.apache.phoenix.util.TestUtil;
 import org.junit.BeforeClass;
 import org.junit.Test;
+import org.junit.experimental.categories.Category;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 
@@ -60,6 +62,7 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 
+@Category(ParallelStatsDisabledTest.class)
 @RunWith(Parameterized.class)
 public class ImmutableIndexExtendedIT extends ParallelStatsDisabledIT {
 
@@ -240,10 +243,10 @@ public class ImmutableIndexExtendedIT extends ParallelStatsDisabledIT {
     private static void verifyRowCountForEmptyCol(Connection conn, String indexTable,
             int expectedVerifiedCount, int expectedUnverifiedCount) throws Exception {
 
-        assertEquals(expectedVerifiedCount,
-                getRowCountForEmptyColValue(conn, indexTable, IndexRegionObserver.VERIFIED_BYTES));
-        assertEquals(expectedUnverifiedCount,
-                getRowCountForEmptyColValue(conn, indexTable, IndexRegionObserver.UNVERIFIED_BYTES));
+        assertEquals(expectedVerifiedCount, getRowCountForEmptyColValue(conn, indexTable,
+                QueryConstants.VERIFIED_BYTES));
+        assertEquals(expectedUnverifiedCount, getRowCountForEmptyColValue(conn, indexTable,
+                QueryConstants.UNVERIFIED_BYTES));
     }
 
     @Test
