@@ -80,8 +80,8 @@ public class PhoenixRpcScheduler extends CompatPhoenixRpcScheduler {
     }
 
     @Override
-    public boolean dispatch(CallRunner callTask) throws InterruptedException, IOException {
-        ServerCall call = callTask.getCall();
+    public boolean compatDispatch(CallRunner callTask) throws IOException, InterruptedException {
+        RpcCall call = callTask.getRpcCall();
         int priority = call.getHeader().getPriority();
         if (indexPriority == priority) {
             return indexCallExecutor.dispatch(callTask);
