@@ -17,15 +17,14 @@
  */
 package org.apache.hadoop.hbase.ipc;
 
-import org.apache.hadoop.hbase.ipc.RpcServer.Call;
 
 public class RpcUtil {
 
-    public static Call getRpcContext() {
+    public static RpcCall getRpcContext() {
         return RpcServer.CurCall.get();
     }
     
-    public static void setRpcContext(Call c){
+    public static void setRpcContext(RpcCall c){
         RpcServer.CurCall.set(c);
     }
 
