@@ -17,11 +17,10 @@
  */
 package org.apache.phoenix.compile;
 
-import com.google.common.annotations.VisibleForTesting;
-import com.google.common.base.Optional;
-import com.google.common.collect.Lists;
-import com.ibm.icu.impl.number.Parse;
-import org.apache.commons.lang.StringUtils;
+import org.apache.phoenix.thirdparty.com.google.common.annotations.VisibleForTesting;
+import org.apache.phoenix.thirdparty.com.google.common.base.Optional;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.phoenix.expression.AndExpression;
 import org.apache.phoenix.expression.CoerceExpression;
 import org.apache.phoenix.expression.ComparisonExpression;
@@ -33,7 +32,6 @@ import org.apache.phoenix.parse.ColumnParseNode;
 import org.apache.phoenix.parse.EqualParseNode;
 import org.apache.phoenix.parse.FilterableStatement;
 import org.apache.phoenix.parse.HintNode;
-import org.apache.phoenix.parse.LiteralParseNode;
 import org.apache.phoenix.parse.OffsetNode;
 import org.apache.phoenix.parse.ParseNode;
 import org.apache.phoenix.parse.RowValueConstructorParseNode;
@@ -47,7 +45,6 @@ import org.apache.phoenix.schema.RowValueConstructorOffsetNotAllowedInQueryExcep
 import org.apache.phoenix.schema.RowValueConstructorOffsetNotCoercibleException;
 import org.apache.phoenix.schema.TypeMismatchException;
 import org.apache.phoenix.util.IndexUtil;
-import org.apache.phoenix.util.ParseNodeUtil;
 import org.apache.phoenix.util.ScanUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
