@@ -27,6 +27,7 @@ import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
 import org.apache.phoenix.exception.SQLExceptionCode;
 import org.apache.phoenix.expression.Expression;
+import org.apache.phoenix.expression.LiteralExpression;
 import org.apache.phoenix.jdbc.PhoenixStatement;
 import org.apache.phoenix.parse.ParseNode;
 import org.apache.phoenix.parse.SequenceValueParseNode;
@@ -50,9 +51,9 @@ public class SequenceManager {
     private int[] sequencePosition;
     private List<SequenceAllocation> nextSequences;
     private List<SequenceKey> currentSequences;
-    private final Map<SequenceKey,SequenceValueExpression> sequenceMap = Maps.newHashMap();
+    private final Map<SequenceKey, SequenceValueExpression> sequenceMap = Maps.newHashMap();
     private final BitSet isNextSequence = new BitSet();
-    
+
     public SequenceManager(PhoenixStatement statement) {
         this.statement = statement;
     }
@@ -130,64 +131,78 @@ public class SequenceManager {
         int nSaltBuckets = statement.getConnection().getQueryServices().getSequenceSaltBuckets();
         ParseNode numToAllocateNode = node.getNumToAllocateNode();
         
-        long numToAllocate = determineNumToAllocate(tableName, numToAllocateNode);
+        Expression numToAllocateExp = numToAllocateExpression(tableName, numToAllocateNode);
         SequenceKey key = new SequenceKey(tenantId, tableName.getSchemaName(), tableName.getTableName(), nSaltBuckets);
+
         SequenceValueExpression expression = sequenceMap.get(key);
         if (expression == null) {
             int index = sequenceMap.size();
-            expression = new SequenceValueExpression(key, node.getOp(), index, numToAllocate);
-            sequenceMap.put(key, expression);
-        } else if (expression.op != node.getOp() || expression.getNumToAllocate() < numToAllocate) {
-            // Keep the maximum allocation size we see in a statement
+            expression = new SequenceValueExpression(key, node.getOp(), index, numToAllocateExp);
+        } else {
+            // Add the new numToAllocateExp to the expression
             SequenceValueExpression oldExpression = expression;
-            expression = new SequenceValueExpression(key, node.getOp(), expression.getIndex(), Math.max(expression.getNumToAllocate(), numToAllocate));
-            if (oldExpression.getNumToAllocate() < numToAllocate) {
-                // If we found a NEXT VALUE expression with a higher number to allocate
-                // We override the original expression
-                sequenceMap.put(key, expression);
-            }
-        } 
+            expression = new SequenceValueExpression(oldExpression, node.getOp(), numToAllocateExp);
+        }
+        sequenceMap.put(key, expression);
+
         // If we see a NEXT and a CURRENT, treat the CURRENT just like a NEXT
         if (node.getOp() == Op.NEXT_VALUE) {
             isNextSequence.set(expression.getIndex());
         }
-           
+
         return expression;
     }
 
+    private Expression numToAllocateExpression(TableName tableName, ParseNode numToAllocateNode) throws SQLException {
+        if (numToAllocateNode != null) {
+            final StatementContext context = new StatementContext(statement);
+            ExpressionCompiler expressionCompiler = new ExpressionCompiler(context);
+            return numToAllocateNode.accept(expressionCompiler);
+        } else {
+            // Standard Sequence Allocation Behavior
+            return LiteralExpression.newConstant(SequenceUtil.DEFAULT_NUM_SLOTS_TO_ALLOCATE);
+        }
+    }
+
     /**
      * If caller specified used NEXT <n> VALUES FOR <seq> expression then we have set the numToAllocate.
      * If numToAllocate is > 1 we treat this as a bulk reservation of a block of sequence slots.
      * 
-     * @throws a SQLException if we can't compile the expression
+     * @throws a SQLException if we can't evaluate the expression
      */
-    private long determineNumToAllocate(TableName sequenceName, ParseNode numToAllocateNode)
+    private long determineNumToAllocate(SequenceValueExpression expression)
             throws SQLException {
 
-        if (numToAllocateNode != null) {
-            final StatementContext context = new StatementContext(statement);
-            ExpressionCompiler expressionCompiler = new ExpressionCompiler(context);
-            Expression expression = numToAllocateNode.accept(expressionCompiler);
+        final StatementContext context = new StatementContext(statement);
+        long maxNumToAllocate = 0;
+        for (Expression numToAllocateExp : expression.getNumToAllocateExpressions()) {
             ImmutableBytesWritable ptr = context.getTempPtr();
-            expression.evaluate(null, ptr);
-            if (ptr.getLength() == 0 || !expression.getDataType().isCoercibleTo(PLong.INSTANCE)) {
-                throw SequenceUtil.getException(sequenceName.getSchemaName(), sequenceName.getTableName(), SQLExceptionCode.NUM_SEQ_TO_ALLOCATE_MUST_BE_CONSTANT);
+            numToAllocateExp.evaluate(null, ptr);
+            if (ptr.getLength() == 0 || !numToAllocateExp.getDataType().isCoercibleTo(PLong.INSTANCE)) {
+                throw SequenceUtil.getException(expression.getKey().getSchemaName(),
+                    expression.getKey().getSequenceName(),
+                    SQLExceptionCode.NUM_SEQ_TO_ALLOCATE_MUST_BE_CONSTANT);
             }
             
             // Parse <n> and make sure it is greater than 0. We don't support allocating 0 or negative values!
-            long numToAllocate = (long) PLong.INSTANCE.toObject(ptr, expression.getDataType());
+            long numToAllocate = (long) PLong.INSTANCE.toObject(ptr, numToAllocateExp.getDataType());
             if (numToAllocate < 1) {
-                throw SequenceUtil.getException(sequenceName.getSchemaName(), sequenceName.getTableName(), SQLExceptionCode.NUM_SEQ_TO_ALLOCATE_MUST_BE_CONSTANT);
+                throw SequenceUtil.getException(expression.getKey().getSchemaName(),
+                    expression.getKey().getSequenceName(),
+                    SQLExceptionCode.NUM_SEQ_TO_ALLOCATE_MUST_BE_CONSTANT);
+            }
+            if (numToAllocate > maxNumToAllocate) {
+                maxNumToAllocate = numToAllocate;
             }
-            return numToAllocate;
-            
-        } else {
-            // Standard Sequence Allocation Behavior
-            return SequenceUtil.DEFAULT_NUM_SLOTS_TO_ALLOCATE;
         }
+
+        return maxNumToAllocate;
     }
-    
+
     public void validateSequences(Sequence.ValueOp action) throws SQLException {
+        if (action == Sequence.ValueOp.NOOP) {
+            return;
+        }
         if (sequenceMap.isEmpty()) {
             return;
         }
@@ -198,7 +213,8 @@ public class SequenceManager {
         currentSequences = Lists.newArrayListWithExpectedSize(maxSize);
         for (Map.Entry<SequenceKey, SequenceValueExpression> entry : sequenceMap.entrySet()) {
             if (isNextSequence.get(entry.getValue().getIndex())) {
-                nextSequences.add(new SequenceAllocation(entry.getKey(), entry.getValue().getNumToAllocate()));
+                nextSequences.add(new SequenceAllocation(entry.getKey(),
+                    determineNumToAllocate(entry.getValue())));
             } else {
                 currentSequences.add(entry.getKey());
             }
