@@ -87,6 +87,7 @@ public class StatementContext {
     private final OverAllQueryMetrics overAllQueryMetrics;
     private QueryLogger queryLogger;
     private boolean isClientSideUpsertSelect;
+    private boolean isUncoveredIndex;
     
     public StatementContext(PhoenixStatement statement) {
         this(statement, new Scan());
@@ -334,6 +335,14 @@ public class StatementContext {
         this.isClientSideUpsertSelect = isClientSideUpsertSelect;
     }
 
+    public boolean isUncoveredIndex() {
+        return isUncoveredIndex;
+    }
+
+    public void setUncoveredIndex(boolean isUncoveredIndex) {
+        this.isUncoveredIndex = isUncoveredIndex;
+    }
+
     /*
      * setRetryingPersistentCache can be used to override the USE_PERSISTENT_CACHE hint and disable the use of the
      * persistent cache for a specific cache ID. This can be used to retry queries that failed when using the persistent
