@@ -27,6 +27,7 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.Properties;
 import java.util.TimerTask;
 import java.util.concurrent.ScheduledThreadPoolExecutor;
@@ -39,19 +40,19 @@ import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.CoprocessorEnvironment;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.client.HTableInterface;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.Scan;
-import org.apache.hadoop.hbase.coprocessor.BaseRegionObserver;
+import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.coprocessor.ObserverContext;
+import org.apache.hadoop.hbase.coprocessor.RegionCoprocessor;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
+import org.apache.hadoop.hbase.coprocessor.RegionObserver;
 import org.apache.hadoop.hbase.filter.CompareFilter;
 import org.apache.hadoop.hbase.filter.SingleColumnValueFilter;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
 import org.apache.hadoop.hbase.regionserver.RegionScanner;
 import org.apache.hadoop.hbase.security.User;
 import org.apache.hadoop.hbase.util.Pair;
-
 import org.apache.phoenix.cache.GlobalCache;
 import org.apache.phoenix.compile.MutationPlan;
 import org.apache.phoenix.compile.PostDDLCompiler;
@@ -86,10 +87,10 @@ import org.apache.phoenix.util.UpgradeUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.annotations.VisibleForTesting;
-import com.google.common.collect.ImmutableList;
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.annotations.VisibleForTesting;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableList;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 
 
 /**
@@ -97,7 +98,7 @@ import com.google.common.collect.Maps;
  * to SYSTEM.TABLE.
  */
 @SuppressWarnings("deprecation")
-public class MetaDataRegionObserver extends BaseRegionObserver {
+public class MetaDataRegionObserver implements RegionObserver,RegionCoprocessor {
     public static final Logger LOGGER = LoggerFactory.getLogger(MetaDataRegionObserver.class);
     public static final String REBUILD_INDEX_APPEND_TO_URL_STRING = "REBUILDINDEX";
     // PHOENIX-5094 To differentiate the increment in PENDING_DISABLE_COUNT made by client or index
@@ -122,6 +123,11 @@ public class MetaDataRegionObserver extends BaseRegionObserver {
         executor.shutdownNow();
         GlobalCache.getInstance(c.getEnvironment()).getMetaDataCache().invalidateAll();
     }
+    
+    @Override
+    public Optional<RegionObserver> getRegionObserver() {
+      return Optional.of(this);
+    }
 
     @Override
     public void start(CoprocessorEnvironment env) throws IOException {
@@ -159,17 +165,17 @@ public class MetaDataRegionObserver extends BaseRegionObserver {
         Runnable r = new Runnable() {
             @Override
             public void run() {
-                HTableInterface metaTable = null;
-                HTableInterface statsTable = null;
+                Table metaTable = null;
+                Table statsTable = null;
                 try {
                     ReadOnlyProps props=new ReadOnlyProps(env.getConfiguration().iterator());
                     Thread.sleep(1000);
-                    metaTable = env.getTable(
+                    metaTable = env.getConnection().getTable(
                             SchemaUtil.getPhysicalName(PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME_BYTES, props));
-                    statsTable = env.getTable(
+                    statsTable = env.getConnection().getTable(
                             SchemaUtil.getPhysicalName(PhoenixDatabaseMetaData.SYSTEM_STATS_NAME_BYTES, props));
-                    final HTableInterface mTable=metaTable;
-                    final HTableInterface sTable=statsTable;
+                    final Table mTable=metaTable;
+                    final Table sTable=statsTable;
                     User.runAsLoginUser(new PrivilegedExceptionAction<Void>() {
                         @Override
                         public Void run() throws Exception {
@@ -181,8 +187,8 @@ public class MetaDataRegionObserver extends BaseRegionObserver {
                     });
 
                 } catch (Exception exception) {
-                    LOGGER.warn("Exception while truncate stats.., please check and delete stats " +
-                            "manually inorder to get proper result with old client!!");
+                    LOGGER.warn("Exception while truncate stats..,"
+                            + " please check and delete stats manually inorder to get proper result with old client!!");
                     LOGGER.warn(exception.getStackTrace().toString());
                 } finally {
                     try {
@@ -261,12 +267,13 @@ public class MetaDataRegionObserver extends BaseRegionObserver {
                     indexesIncremented.add(index);
                 }catch(Exception e) {
                     LOGGER.warn("Decrement  of -" + PENDING_DISABLE_INACTIVE_STATE_COUNT
-                            + " for index :" + index.getName().getString() + "of table: "
+                            +" for index :" + index.getName().getString() + "of table: "
                             + dataPTable.getName().getString(), e);
                 }
             }
             return indexesIncremented;
         }
+
         @Override
         public void run() {
             // FIXME: we should replay the data table Put, as doing a partial index build would only add
@@ -461,7 +468,7 @@ public class MetaDataRegionObserver extends BaseRegionObserver {
 						List<Pair<PTable,Long>> pairs = entry.getValue();
                         List<PTable> indexesToPartiallyRebuild = Lists.newArrayListWithExpectedSize(pairs.size());
 						try (
-                        HTableInterface metaTable = env.getTable(
+                        Table metaTable = env.getConnection().getTable(
 								SchemaUtil.getPhysicalName(PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME_BYTES, props))) {
 							long earliestDisableTimestamp = Long.MAX_VALUE;
                             long latestUpperBoundTimestamp = Long.MIN_VALUE;
@@ -501,13 +508,13 @@ public class MetaDataRegionObserver extends BaseRegionObserver {
 							}
 							// No indexes are disabled, so skip this table
 							if (earliestDisableTimestamp == Long.MAX_VALUE) {
-		                        LOGGER.debug("No indexes are disabled so continuing");
+                                LOGGER.debug("No indexes are disabled so continuing");
 								continue;
 							}
 							long scanBeginTime = Math.max(0, earliestDisableTimestamp - backwardOverlapDurationMs);
                             long scanEndTime = Math.min(latestUpperBoundTimestamp,
                                     getTimestampForBatch(scanBeginTime,batchExecutedPerTableMap.get(dataPTable.getName())));
-							LOGGER.info("Starting to build " + dataPTable + " indexes "
+                            LOGGER.info("Starting to build " + dataPTable + " indexes "
                                     + indexesToPartiallyRebuild + " from timestamp=" +
                                     scanBeginTime + " until " + scanEndTime);
 							
@@ -528,21 +535,18 @@ public class MetaDataRegionObserver extends BaseRegionObserver {
 							byte[] attribValue = ByteUtil.copyKeyBytesIfNecessary(indexMetaDataPtr);
 							dataTableScan.setAttribute(PhoenixIndexCodec.INDEX_PROTO_MD, attribValue);
 							ScanUtil.setClientVersion(dataTableScan, MetaDataProtocol.PHOENIX_VERSION);
-                            LOGGER.info("Starting to partially build indexes:" +
-                                    indexesToPartiallyRebuild + " on data table:" +
-                                    dataPTable.getName() + " with the earliest disable timestamp:"
+                            LOGGER.info("Starting to partially build indexes:" + indexesToPartiallyRebuild
+                                    + " on data table:" + dataPTable.getName() + " with the earliest disable timestamp:"
                                     + earliestDisableTimestamp + " till "
-                                    + (scanEndTime == HConstants.LATEST_TIMESTAMP ?
-                                    "LATEST_TIMESTAMP" : scanEndTime));
+                                    + (scanEndTime == HConstants.LATEST_TIMESTAMP ? "LATEST_TIMESTAMP" : scanEndTime));
 							MutationState mutationState = plan.execute();
 							long rowCount = mutationState.getUpdateCount();
 							decrementIndexesPendingDisableCount(conn, dataPTable, indexesToPartiallyRebuild);
-							if (scanEndTime == latestUpperBoundTimestamp) {
-                                LOGGER.info("Rebuild completed for all inactive/disabled indexes" +
-                                        " in data table:" + dataPTable.getName());
+                            if (scanEndTime == latestUpperBoundTimestamp) {
+                                LOGGER.info("Rebuild completed for all inactive/disabled indexes in data table:"
+                                        + dataPTable.getName());
                             }
-                            LOGGER.info(" no. of datatable rows read in rebuilding process is "
-                                    + rowCount);
+                            LOGGER.info(" no. of datatable rows read in rebuilding process is " + rowCount);
 							for (PTable indexPTable : indexesToPartiallyRebuild) {
 								String indexTableFullName = SchemaUtil.getTableName(
 										indexPTable.getSchemaName().getString(),
@@ -552,8 +556,7 @@ public class MetaDataRegionObserver extends BaseRegionObserver {
 								        IndexUtil.updateIndexState(conn, indexTableFullName, PIndexState.ACTIVE, 0L,
 								            latestUpperBoundTimestamp);
 								        batchExecutedPerTableMap.remove(dataPTable.getName());
-								        LOGGER.info("Making Index:" + indexPTable.getTableName() +
-                                                " active after rebuilding");
+                                        LOGGER.info("Making Index:" + indexPTable.getTableName() + " active after rebuilding");
 								    } else {
 								        // Increment timestamp so that client sees updated disable timestamp
 								        IndexUtil.updateIndexState(conn, indexTableFullName, indexPTable.getIndexState(),
@@ -563,37 +566,34 @@ public class MetaDataRegionObserver extends BaseRegionObserver {
 								            noOfBatches = 0l;
 								        }
 								        batchExecutedPerTableMap.put(dataPTable.getName(), ++noOfBatches);
-								        LOGGER.info(
-								            "During Round-robin build: Successfully updated " +
-                                                    "index disabled timestamp  for "
+                                        LOGGER.info(
+								            "During Round-robin build: Successfully updated index disabled timestamp  for "
 								                + indexTableFullName + " to " + scanEndTime);
 								    }
 								} catch (SQLException e) {
-								    LOGGER.error("Unable to rebuild " + dataPTable + " index " +
-                                            indexTableFullName, e);
+                                    LOGGER.error("Unable to rebuild " + dataPTable + " index " + indexTableFullName, e);
 								}
 							}
 						} catch (Exception e) {
-							LOGGER.error("Unable to rebuild " + dataPTable + " indexes " +
-                                    indexesToPartiallyRebuild, e);
+                            LOGGER.error("Unable to rebuild " + dataPTable + " indexes " + indexesToPartiallyRebuild, e);
 						}
 					}
 				}
 			} catch (Throwable t) {
-				LOGGER.warn("ScheduledBuildIndexTask failed!", t);
+                LOGGER.warn("ScheduledBuildIndexTask failed!", t);
 			} finally {
 				if (scanner != null) {
 					try {
 						scanner.close();
 					} catch (IOException ignored) {
-						LOGGER.debug("ScheduledBuildIndexTask can't close scanner.", ignored);
+                        LOGGER.debug("ScheduledBuildIndexTask can't close scanner.", ignored);
 					}
 				}
 				if (conn != null) {
 					try {
 						conn.close();
 					} catch (SQLException ignored) {
-						LOGGER.debug("ScheduledBuildIndexTask can't close connection", ignored);
+                        LOGGER.debug("ScheduledBuildIndexTask can't close connection", ignored);
 					}
 				}
 			}
