@@ -27,11 +27,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
-import com.google.common.base.Optional;
-import org.apache.commons.math3.util.Pair;
-import org.apache.phoenix.compile.ExplainPlanAttributes;
-import org.apache.phoenix.compile.ExplainPlanAttributes
-    .ExplainPlanAttributesBuilder;
+import org.apache.commons.lang3.tuple.Pair;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
@@ -41,6 +37,9 @@ import org.apache.hadoop.io.WritableUtils;
 import org.apache.htrace.TraceScope;
 import org.apache.phoenix.cache.ServerCacheClient.ServerCache;
 import org.apache.phoenix.compile.ExplainPlan;
+import org.apache.phoenix.compile.ExplainPlanAttributes;
+import org.apache.phoenix.compile.ExplainPlanAttributes
+    .ExplainPlanAttributesBuilder;
 import org.apache.phoenix.compile.FromCompiler;
 import org.apache.phoenix.compile.GroupByCompiler.GroupBy;
 import org.apache.phoenix.compile.OrderByCompiler.OrderBy;
@@ -77,6 +76,9 @@ import org.apache.phoenix.schema.PTable.ImmutableStorageScheme;
 import org.apache.phoenix.schema.PTable.IndexType;
 import org.apache.phoenix.schema.PTableType;
 import org.apache.phoenix.schema.TableRef;
+import org.apache.phoenix.thirdparty.com.google.common.base.Optional;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableSet;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 import org.apache.phoenix.trace.TracingIterator;
 import org.apache.phoenix.trace.util.Tracing;
 import org.apache.phoenix.util.ByteUtil;
@@ -87,9 +89,6 @@ import org.apache.phoenix.util.ScanUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.collect.ImmutableSet;
-import com.google.common.collect.Lists;
-
 
 
 /**
@@ -219,7 +218,7 @@ public abstract class BaseQueryPlan implements QueryPlan {
 
     @Override
     public final ResultIterator iterator(ParallelScanGrouper scanGrouper, Scan scan) throws SQLException {
-        return iterator(Collections.<ImmutableBytesPtr,ServerCache>emptyMap(), scanGrouper, scan);
+        return iterator(Collections.emptyMap(), scanGrouper, scan);
     }
         
 	private ResultIterator getWrappedIterator(final Map<ImmutableBytesPtr,ServerCache> dependencies,
@@ -237,6 +236,10 @@ public abstract class BaseQueryPlan implements QueryPlan {
 		return wrappedIterator;
 	}
 
+    protected void setScanReversedWhenOrderByIsReversed(Scan scan) {
+        ScanUtil.setReversed(scan);
+    }
+
     public final ResultIterator iterator(final Map<ImmutableBytesPtr,ServerCache> caches,
             ParallelScanGrouper scanGrouper, Scan scan) throws SQLException {
          if (scan == null) {
@@ -271,7 +274,7 @@ public abstract class BaseQueryPlan implements QueryPlan {
         }
         
         if (OrderBy.REV_ROW_KEY_ORDER_BY.equals(orderBy)) {
-            ScanUtil.setReversed(scan);
+            setScanReversedWhenOrderByIsReversed(scan);
             // After HBASE-16296 is resolved, we no longer need to set
             // scan caching
         }
@@ -324,10 +327,16 @@ public abstract class BaseQueryPlan implements QueryPlan {
 
         ScanUtil.setTenantId(scan, tenantIdBytes);
         String customAnnotations = LogUtil.customAnnotationsToString(connection);
-        ScanUtil.setCustomAnnotations(scan, customAnnotations == null ? null : customAnnotations.getBytes());
-        // Set local index related scan attributes. 
-        if (table.getIndexType() == IndexType.LOCAL) {
-            ScanUtil.setLocalIndex(scan);
+        ScanUtil.setCustomAnnotations(scan,
+                customAnnotations == null ? null : customAnnotations.getBytes());
+        // Set index related scan attributes.
+        if (table.getType() == PTableType.INDEX) {
+            if (table.getIndexType() == IndexType.LOCAL) {
+                ScanUtil.setLocalIndex(scan);
+            } else if (context.isUncoveredIndex()) {
+                ScanUtil.setUncoveredGlobalIndex(scan);
+            }
+
             Set<PColumn> dataColumns = context.getDataColumns();
             // If any data columns to join back from data table are present then we set following attributes
             // 1. data columns to be projected and their key value schema.
@@ -351,11 +360,12 @@ public abstract class BaseQueryPlan implements QueryPlan {
                 KeyValueSchema schema = ProjectedColumnExpression.buildSchema(dataColumns);
                 // Set key value schema of the data columns.
                 serializeSchemaIntoScan(scan, schema);
-                
-                // Set index maintainer of the local index.
-                serializeIndexMaintainerIntoScan(scan, dataTable);
-                // Set view constants if exists.
-                serializeViewConstantsIntoScan(scan, dataTable);
+                if (table.getIndexType() == IndexType.LOCAL) {
+                    // Set index maintainer of the local index.
+                    serializeIndexMaintainerIntoScan(scan, dataTable);
+                    // Set view constants if exists.
+                    serializeViewConstantsIntoScan(scan, dataTable);
+                }
             }
         }
         
@@ -522,8 +532,8 @@ public abstract class BaseQueryPlan implements QueryPlan {
         ResultIterator iterator = iterator();
         Pair<List<String>, ExplainPlanAttributes> planSteps =
             getPlanStepsV2(iterator);
-        ExplainPlan explainPlan = new ExplainPlan(planSteps.getFirst(),
-            planSteps.getSecond());
+        ExplainPlan explainPlan = new ExplainPlan(planSteps.getLeft(),
+            planSteps.getRight());
         iterator.close();
         return explainPlan;
     }
@@ -540,7 +550,7 @@ public abstract class BaseQueryPlan implements QueryPlan {
         ExplainPlanAttributesBuilder builder =
             new ExplainPlanAttributesBuilder();
         iterator.explain(planSteps, builder);
-        return new Pair<>(planSteps, builder.build());
+        return Pair.of(planSteps, builder.build());
     }
 
     @Override
