@@ -44,11 +44,11 @@ import org.apache.phoenix.util.ScanUtil;
 import org.apache.phoenix.util.ScanUtil.BytesComparator;
 import org.apache.phoenix.util.SchemaUtil;
 
-import com.google.common.base.Objects;
-import com.google.common.collect.Lists;
-import com.google.common.hash.HashFunction;
-import com.google.common.hash.Hasher;
-import com.google.common.hash.Hashing;
+import org.apache.phoenix.thirdparty.com.google.common.base.Objects;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.hash.HashFunction;
+import org.apache.phoenix.thirdparty.com.google.common.hash.Hasher;
+import org.apache.phoenix.thirdparty.com.google.common.hash.Hashing;
 
 
 /**
