@@ -21,14 +21,14 @@ package org.apache.phoenix.hbase.index.table;
 import java.io.IOException;
 import java.util.concurrent.ExecutorService;
 
-import org.apache.hadoop.hbase.client.HTableInterface;
+import org.apache.hadoop.hbase.client.Table;
 import org.apache.phoenix.hbase.index.util.ImmutableBytesPtr;
 
 public interface HTableFactory {
 
-  public HTableInterface getTable(ImmutableBytesPtr tablename) throws IOException;
+  public Table getTable(ImmutableBytesPtr tablename) throws IOException;
 
   public void shutdown();
 
-  public HTableInterface getTable(ImmutableBytesPtr tablename, ExecutorService pool) throws IOException;
+  public Table getTable(ImmutableBytesPtr tablename, ExecutorService pool) throws IOException;
 }
\ No newline at end of file
