@@ -20,11 +20,15 @@ package org.apache.phoenix.iterate;
 
 import static org.apache.phoenix.coprocessor.ScanRegionObserver.WILDCARD_SCAN_INCLUDES_DYNAMIC_COLUMNS;
 import static org.apache.phoenix.schema.types.PDataType.TRUE_BYTES;
-import static org.apache.phoenix.util.ScanUtil.getDummyResult;
-import static org.apache.phoenix.util.ScanUtil.getPageSizeMsForRegionScanner;
-import static org.apache.phoenix.util.ScanUtil.isDummy;
 
 import org.apache.hadoop.hbase.CellUtil;
+import org.apache.phoenix.coprocessor.UncoveredGlobalIndexRegionScanner;
+import org.apache.phoenix.coprocessor.UncoveredLocalIndexRegionScanner;
+import org.apache.phoenix.schema.KeyValueSchema;
+import org.apache.phoenix.schema.PColumn;
+import org.apache.phoenix.schema.PColumnImpl;
+import org.apache.phoenix.schema.PTable;
+import org.apache.phoenix.schema.ValueBitSet;
 import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableList;
 
 import org.apache.hadoop.hbase.Cell;
@@ -51,10 +55,6 @@ import org.apache.phoenix.expression.KeyValueColumnExpression;
 import org.apache.phoenix.hbase.index.covered.update.ColumnReference;
 import org.apache.phoenix.index.IndexMaintainer;
 import org.apache.phoenix.query.QueryConstants;
-import org.apache.phoenix.schema.KeyValueSchema;
-import org.apache.phoenix.schema.PColumn;
-import org.apache.phoenix.schema.PColumnImpl;
-import org.apache.phoenix.schema.ValueBitSet;
 import org.apache.phoenix.schema.tuple.MultiKeyValueTuple;
 import org.apache.phoenix.schema.tuple.PositionBasedResultTuple;
 import org.apache.phoenix.schema.tuple.ResultTuple;
@@ -115,27 +115,31 @@ public abstract class RegionScannerFactory {
    * @param viewConstants
    */
   public RegionScanner getWrappedScanner(final RegionCoprocessorEnvironment env,
-      final RegionScanner s, final Set<KeyValueColumnExpression> arrayKVRefs,
+      final RegionScanner regionScanner, final Set<KeyValueColumnExpression> arrayKVRefs,
       final Expression[] arrayFuncRefs, final int offset, final Scan scan,
       final ColumnReference[] dataColumns, final TupleProjector tupleProjector,
       final Region dataRegion, final IndexMaintainer indexMaintainer,
       PhoenixTransactionContext tx,
       final byte[][] viewConstants, final KeyValueSchema kvSchema,
       final ValueBitSet kvSchemaBitSet, final TupleProjector projector,
-      final ImmutableBytesWritable ptr, final boolean useQualifierAsListIndex) {
+      final ImmutableBytesWritable ptr, final boolean useQualifierAsListIndex) throws IOException {
     return new RegionScanner() {
-
+      private RegionScanner s = regionScanner;
       private RegionInfo regionInfo = env.getRegionInfo();
       private byte[] actualStartKey = getActualStartKey();
       private boolean useNewValueColumnQualifier = EncodedColumnsUtil.useNewValueColumnQualifier(scan);
-      final long pageSizeMs = getPageSizeMsForRegionScanner(scan);
+      final long pageSizeMs = ScanUtil.getPageSizeMsForRegionScanner(scan);
       Expression extraWhere = null;
       long extraLimit = -1;
 
       {
-          // for local indexes construct the row filter for uncovered columns if it exists
-          if (ScanUtil.isLocalIndex(scan)) {
-              byte[] expBytes = scan.getAttribute(BaseScannerRegionObserver.LOCAL_INDEX_FILTER);
+          // for indexes construct the row filter for uncovered columns if it exists
+          if (ScanUtil.isLocalOrUncoveredGlobalIndex(scan)) {
+              byte[] expBytes = scan.getAttribute(BaseScannerRegionObserver.INDEX_FILTER);
+              if (expBytes == null) {
+                  // For older clients
+                  expBytes = scan.getAttribute(BaseScannerRegionObserver.LOCAL_INDEX_FILTER);
+              }
               if (expBytes != null) {
                   try {
                       ByteArrayInputStream stream = new ByteArrayInputStream(expBytes);
@@ -147,10 +151,37 @@ public abstract class RegionScannerFactory {
                       throw new RuntimeException(io);
                   }
               }
-              byte[] limitBytes = scan.getAttribute(BaseScannerRegionObserver.LOCAL_INDEX_LIMIT);
+              byte[] limitBytes = scan.getAttribute(BaseScannerRegionObserver.INDEX_LIMIT);
+              if (limitBytes == null) {
+                  // For older clients
+                  limitBytes = scan.getAttribute(BaseScannerRegionObserver.LOCAL_INDEX_LIMIT);
+              }
               if (limitBytes != null) {
                   extraLimit = Bytes.toLong(limitBytes);
               }
+              if (ScanUtil.isLocalOrUncoveredGlobalIndex(scan) && tupleProjector != null) {
+                  PTable.ImmutableStorageScheme storageScheme =
+                          indexMaintainer.getIndexStorageScheme();
+                  Scan dataTableScan = new Scan();
+                  for (int i = 0; i < dataColumns.length; i++) {
+                      if (storageScheme ==
+                              PTable.ImmutableStorageScheme.SINGLE_CELL_ARRAY_WITH_OFFSETS) {
+                          dataTableScan.addFamily(dataColumns[i].getFamily());
+                      } else {
+                          dataTableScan.addColumn(dataColumns[i].getFamily(),
+                                  dataColumns[i].getQualifier());
+                      }
+                  }
+                  if (ScanUtil.isLocalIndex(scan)) {
+                    s = new UncoveredLocalIndexRegionScanner(regionScanner, dataRegion, scan, env,
+                            dataTableScan, tupleProjector, indexMaintainer, viewConstants, ptr,
+                            pageSizeMs, offset, actualStartKey);
+                  } else {
+                    s = new UncoveredGlobalIndexRegionScanner(regionScanner, dataRegion, scan, env,
+                            dataTableScan, tupleProjector, indexMaintainer, viewConstants, ptr,
+                            pageSizeMs);
+                  }
+              }
           }
       }
 
@@ -165,7 +196,7 @@ public abstract class RegionScannerFactory {
       public boolean next(List<Cell> results) throws IOException {
         try {
           boolean next = s.next(results);
-          if (isDummy(results)) {
+          if (ScanUtil.isDummy(results)) {
             return true;
           }
           return next;
@@ -209,26 +240,23 @@ public abstract class RegionScannerFactory {
       public boolean nextRaw(List<Cell> result) throws IOException {
         try {
           boolean next = s.nextRaw(result);
-          if (isDummy(result)) {
+          if (ScanUtil.isDummy(result)) {
             return true;
           }
           if (result.size() == 0) {
             return next;
           }
-          if (ScanUtil.isLocalIndex(scan) && !ScanUtil.isAnalyzeTable(scan)) {
-            if(actualStartKey!=null) {
-              next = scanTillScanStartRow(s, arrayKVRefs, arrayFuncRefs, result,
-                  null);
-              if (result.isEmpty() || isDummy(result)) {
-                return next;
+          if ((ScanUtil.isLocalOrUncoveredGlobalIndex(scan))
+                  && !ScanUtil.isAnalyzeTable(scan)) {
+            if (ScanUtil.isLocalIndex(scan) && tupleProjector == null) {
+              if (actualStartKey != null) {
+                next = scanTillScanStartRow(s,  result, null);
+                if (result.isEmpty() || ScanUtil.isDummy(result)) {
+                  return next;
+                }
               }
+              IndexUtil.wrapResultUsingOffset(result, offset);
             }
-            /* In the following, c is only used when data region is null.
-            dataRegion will never be null in case of non-coprocessor call,
-            therefore no need to refactor
-             */
-            IndexUtil.wrapResultUsingOffset(env, result, offset, dataColumns,
-                tupleProjector, dataRegion, indexMaintainer, viewConstants, ptr);
 
             if (extraWhere != null) {
                 Tuple merged = useQualifierAsListIndex ? new PositionBasedResultTuple(result) :
@@ -341,9 +369,8 @@ public abstract class RegionScannerFactory {
        * TODO try to fix this case in LocalIndexStoreFileScanner when there is a merge.
        */
       private boolean scanTillScanStartRow(final RegionScanner s,
-          final Set<KeyValueColumnExpression> arrayKVRefs,
-          final Expression[] arrayFuncRefs, List<Cell> result,
-          ScannerContext scannerContext) throws IOException {
+                                           List<Cell> result,
+                                           ScannerContext scannerContext) throws IOException {
         boolean next = true;
         Cell firstCell = result.get(0);
         long startTime = EnvironmentEdgeManager.currentTimeMillis();
@@ -352,7 +379,7 @@ public abstract class RegionScannerFactory {
           if (EnvironmentEdgeManager.currentTimeMillis() - startTime >= pageSizeMs) {
             byte[] rowKey = CellUtil.cloneRow(result.get(0));
             result.clear();
-            getDummyResult(rowKey, result);
+            ScanUtil.getDummyResult(rowKey, result);
             return true;
           }
           result.clear();
@@ -364,7 +391,7 @@ public abstract class RegionScannerFactory {
           if (result.isEmpty()) {
             return next;
           }
-          if (isDummy(result)) {
+          if (ScanUtil.isDummy(result)) {
             return true;
           }
           firstCell = result.get(0);
