@@ -17,6 +17,7 @@
  */
 package org.apache.phoenix.jdbc;
 
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.SYSTEM_CATALOG_SCHEMA;
 import static org.apache.phoenix.thirdparty.com.google.common.base.Preconditions.checkNotNull;
 import static java.util.Collections.emptyMap;
 import static org.apache.phoenix.monitoring.GlobalClientMetrics.GLOBAL_OPEN_INTERNAL_PHOENIX_CONNECTIONS;
@@ -88,9 +89,10 @@ import org.apache.phoenix.query.PropertyPolicyProvider;
 import org.apache.phoenix.query.QueryConstants;
 import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.query.QueryServicesOptions;
+import org.apache.phoenix.schema.ConnectionProperty;
+import org.apache.phoenix.schema.FunctionNotFoundException;
 import org.apache.phoenix.schema.PColumn;
 import org.apache.phoenix.schema.PMetaData;
-import org.apache.phoenix.schema.PMetaData.Pruner;
 import org.apache.phoenix.schema.PName;
 import org.apache.phoenix.schema.PTable;
 import org.apache.phoenix.schema.PTableKey;
@@ -153,7 +155,6 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
     private List<PhoenixStatement> statements = new ArrayList<>();
     private boolean isAutoFlush = false;
     private boolean isAutoCommit = false;
-    private PMetaData metaData;
     private final PName tenantId;
     private final String datePattern;
     private final String timePattern;
@@ -175,9 +176,10 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
     private LogLevel auditLogLevel;
     private Double logSamplingRate;
     private String sourceOfOperation;
+    private static final String[] CONNECTION_PROPERTIES;
 
-    private Object queueCreationLock = new Object(); // lock for the lazy init path of childConnections structure
-    private ConcurrentLinkedQueue<PhoenixConnection> childConnections = null;
+    private final ConcurrentLinkedQueue<PhoenixConnection> childConnections =
+        new ConcurrentLinkedQueue<>();
 
     //For now just the copy constructor paths will have this as true as I don't want to change the
     //public interfaces.
@@ -185,6 +187,7 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
 
     static {
         Tracing.addTraceMetricsSource();
+        CONNECTION_PROPERTIES = PhoenixRuntime.getConnectionProperties();
     }
 
     private static Properties newPropsWithSCN(long scn, Properties props) {
@@ -197,7 +200,7 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
             boolean isDescRowKeyOrderUpgrade, boolean isRunningUpgrade)
                     throws SQLException {
         this(connection.getQueryServices(), connection.getURL(), connection
-                .getClientInfo(), connection.metaData, connection
+                .getClientInfo(), connection
                 .getMutationState(), isDescRowKeyOrderUpgrade,
                 isRunningUpgrade, connection.buildingIndex, true);
         this.isAutoCommit = connection.isAutoCommit;
@@ -214,7 +217,7 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
     public PhoenixConnection(PhoenixConnection connection,
             MutationState mutationState) throws SQLException {
         this(connection.getQueryServices(), connection.getURL(), connection
-                .getClientInfo(), connection.getMetaDataCache(), mutationState,
+                .getClientInfo(), mutationState,
                 connection.isDescVarLengthRowKeyUpgrade(), connection
                 .isRunningUpgrade(), connection.buildingIndex, true);
     }
@@ -225,7 +228,7 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
     }
 
 	public PhoenixConnection(PhoenixConnection connection, Properties props) throws SQLException {
-        this(connection.getQueryServices(), connection.getURL(), props, connection.metaData, connection
+        this(connection.getQueryServices(), connection.getURL(), props, connection
                 .getMutationState(), connection.isDescVarLengthRowKeyUpgrade(),
                 connection.isRunningUpgrade(), connection.buildingIndex, true);
         this.isAutoCommit = connection.isAutoCommit;
@@ -235,20 +238,20 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
     }
 
     public PhoenixConnection(ConnectionQueryServices services, String url,
-            Properties info, PMetaData metaData) throws SQLException {
-        this(services, url, info, metaData, null, false, false, false, false);
+            Properties info) throws SQLException {
+        this(services, url, info, null, false, false, false, false);
     }
 
     public PhoenixConnection(PhoenixConnection connection,
             ConnectionQueryServices services, Properties info)
                     throws SQLException {
-        this(services, connection.url, info, connection.metaData, null,
+        this(services, connection.url, info, null,
                 connection.isDescVarLengthRowKeyUpgrade(), connection
                 .isRunningUpgrade(), connection.buildingIndex, true);
     }
 
     private PhoenixConnection(ConnectionQueryServices services, String url,
-            Properties info, PMetaData metaData, MutationState mutationState,
+            Properties info, MutationState mutationState,
             boolean isDescVarLengthRowKeyUpgrade, boolean isRunningUpgrade,
             boolean buildingIndex, boolean isInternalConnection) throws SQLException {
         GLOBAL_PHOENIX_CONNECTIONS_ATTEMPTED_COUNTER.increment();
@@ -264,8 +267,7 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
         }
 
         // Copy so client cannot change
-        this.info = info == null ? new Properties() : PropertiesUtil
-                .deepCopy(info);
+        this.info = PropertiesUtil.deepCopy(info);
         final PName tenantId = JDBCUtil.getTenantId(url, info);
         if (this.info.isEmpty() && tenantId == null) {
             this.services = services;
@@ -357,29 +359,7 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
         formatters.put(PDecimal.INSTANCE,
                 FunctionArgumentType.NUMERIC.getFormatter(numberPattern));
         formatters.put(PVarbinary.INSTANCE, VarBinaryFormatter.INSTANCE);
-        // We do not limit the metaData on a connection less than the global
-        // one,
-        // as there's not much that will be cached here.
-        Pruner pruner = new Pruner() {
 
-            @Override
-            public boolean prune(PTable table) {
-                long maxTimestamp = scn == null ? HConstants.LATEST_TIMESTAMP
-                        : scn;
-                return (table.getType() != PTableType.SYSTEM && (table
-                        .getTimeStamp() >= maxTimestamp || (table.getTenantId() != null && !Objects
-                        .equal(tenantId, table.getTenantId()))));
-            }
-
-            @Override
-            public boolean prune(PFunction function) {
-                long maxTimestamp = scn == null ? HConstants.LATEST_TIMESTAMP
-                        : scn;
-                return (function.getTimeStamp() >= maxTimestamp || (function
-                        .getTenantId() != null && !Objects.equal(tenantId,
-                                function.getTenantId())));
-            }
-        };
         this.logLevel= LogLevel.valueOf(this.services.getProps().get(QueryServices.LOG_LEVEL,
                 QueryServicesOptions.DEFAULT_LOGGING_LEVEL));
         this.auditLogLevel= LogLevel.valueOf(this.services.getProps().get(QueryServices.AUDIT_LOG_LEVEL,
@@ -388,9 +368,6 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
                 this.services.getProps());
         this.mutationState = mutationState == null ? newMutationState(maxSize,
                 maxSizeBytes) : new MutationState(mutationState, this);
-        this.metaData = metaData;
-        this.metaData.pruneTables(pruner);
-        this.metaData.pruneFunctions(pruner);
         this.services.addConnection(this);
 
         // setup tracing, if its enabled
@@ -437,7 +414,7 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
 
     private static Properties filterKnownNonProperties(Properties info) {
         Properties prunedProperties = info;
-        for (String property : PhoenixRuntime.CONNECTION_PROPERTIES) {
+        for (String property : CONNECTION_PROPERTIES) {
             if (info.containsKey(property)) {
                 if (prunedProperties == info) {
                     prunedProperties = PropertiesUtil.deepCopy(info);
@@ -466,18 +443,10 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
     }
 
     /**
-     * This method, and *only* this method is thread safe
+     * Add connection to the internal childConnections queue
      * @param connection
      */
     public void addChildConnection(PhoenixConnection connection) {
-        //double check for performance
-        if(childConnections == null) {
-            synchronized (queueCreationLock) {
-                if (childConnections == null) {
-                    childConnections = new ConcurrentLinkedQueue<>();
-                }
-            }
-        }
         childConnections.add(connection);
     }
 
@@ -487,9 +456,7 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
      * @param connection
      */
     public void removeChildConnection(PhoenixConnection connection) {
-        if (childConnections != null) {
-            childConnections.remove(connection);
-        }
+        childConnections.remove(connection);
     }
 
     /**
@@ -499,10 +466,7 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
      */
     @VisibleForTesting
     public int getChildConnectionsCount() {
-        if (childConnections != null) {
-            return childConnections.size();
-        }
-        return 0;
+        return childConnections.size();
     }
 
     public Sampler<?> getSampler() {
@@ -642,17 +606,41 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
     }
 
     public PMetaData getMetaDataCache() {
-        return metaData;
+        return getQueryServices().getMetaDataCache();
+    }
+
+    private boolean prune(PTable table) {
+        long maxTimestamp = scn == null ? HConstants.LATEST_TIMESTAMP
+                : scn;
+        return (table.getType() != PTableType.SYSTEM && (table
+                .getTimeStamp() >= maxTimestamp || (table.getTenantId() != null && !Objects
+                .equal(tenantId, table.getTenantId()))));
     }
 
     public PTable getTable(PTableKey key) throws TableNotFoundException {
-        return metaData.getTableRef(key).getTable();
+        return getTableRef(key).getTable();
     }
 
     public PTableRef getTableRef(PTableKey key) throws TableNotFoundException {
-        return metaData.getTableRef(key);
+        PTableRef tableRef = getQueryServices().getMetaDataCache().getTableRef(key);
+        if (prune(tableRef.getTable())) {
+            throw new TableNotFoundException(key.getName());
+        }
+        return  tableRef;
     }
 
+    public boolean prune(PFunction function) {
+        long maxTimestamp = scn == null ? HConstants.LATEST_TIMESTAMP
+                : scn;
+        return (function.getTimeStamp() >= maxTimestamp || (function
+                .getTenantId() != null && !Objects.equal(tenantId,
+                function.getTenantId())));
+    }
+
+    public PFunction getFunction(PTableKey key) throws FunctionNotFoundException {
+        PFunction function = getQueryServices().getMetaDataCache().getFunction(key);
+        return prune(function) ? null : function;
+    }
     protected MutationState newMutationState(int maxSize, long maxSizeBytes) {
         return new MutationState(maxSize, maxSizeBytes, this);
     }
@@ -719,15 +707,11 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
                     traceScope.close();
                 }
                 closeStatements();
-                synchronized (queueCreationLock) {
-                    if (childConnections != null) {
-                        SQLCloseables.closeAllQuietly(childConnections);
-                    }
-                }
+                SQLCloseables.closeAllQuietly(childConnections);
             } finally {
                 services.removeConnection(this);
             }
-            
+
         } finally {
             isClosed = true;
             if(isInternalConnection()){
@@ -794,7 +778,7 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
 
     /**
      * Back-door way to inject processing into walking through a result set
-     * 
+     *
      * @param statementFactory
      * @return PhoenixStatement
      * @throws SQLException
@@ -1156,7 +1140,7 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
     }
 
     public PSchema getSchema(PTableKey key) throws SchemaNotFoundException {
-        return metaData.getSchema(key);
+        return getQueryServices().getMetaDataCache().getSchema(key);
     }
 
     @Override
@@ -1176,45 +1160,38 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
         return 0;
     }
 
+    private boolean useMetaDataCache(PTable table) {
+        return table.getType() == PTableType.SYSTEM
+                || table.getUpdateCacheFrequency() != 0
+                || (Long) ConnectionProperty.UPDATE_CACHE_FREQUENCY.getValue(
+                        getQueryServices().getProps().get(QueryServices.DEFAULT_UPDATE_CACHE_FREQUENCY_ATRRIB)) != 0;
+
+    }
     @Override
     public void addTable(PTable table, long resolvedTime) throws SQLException {
-        metaData.addTable(table, resolvedTime);
-        // Cascade through to connectionQueryServices too
         getQueryServices().addTable(table, resolvedTime);
     }
 
     @Override
     public void updateResolvedTimestamp(PTable table, long resolvedTime)
             throws SQLException {
-        metaData.updateResolvedTimestamp(table, resolvedTime);
-        // Cascade through to connectionQueryServices too
+
         getQueryServices().updateResolvedTimestamp(table, resolvedTime);
     }
 
     @Override
     public void addFunction(PFunction function) throws SQLException {
-        // TODO: since a connection is only used by one thread at a time,
-        // we could modify this metadata in place since it's not shared.
-        if (scn == null || scn > function.getTimeStamp()) {
-            metaData.addFunction(function);
-        }
-        // Cascade through to connectionQueryServices too
         getQueryServices().addFunction(function);
     }
 
     @Override
     public void addSchema(PSchema schema) throws SQLException {
-        metaData.addSchema(schema);
-        // Cascade through to connectionQueryServices too
         getQueryServices().addSchema(schema);
     }
 
     @Override
     public void removeTable(PName tenantId, String tableName,
             String parentTableName, long tableTimeStamp) throws SQLException {
-        metaData.removeTable(tenantId, tableName, parentTableName,
-                tableTimeStamp);
-        // Cascade through to connectionQueryServices too
         getQueryServices().removeTable(tenantId, tableName, parentTableName,
                 tableTimeStamp);
     }
@@ -1222,8 +1199,6 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
     @Override
     public void removeFunction(PName tenantId, String functionName,
             long tableTimeStamp) throws SQLException {
-        metaData.removeFunction(tenantId, functionName, tableTimeStamp);
-        // Cascade through to connectionQueryServices too
         getQueryServices().removeFunction(tenantId, functionName,
                 tableTimeStamp);
     }
@@ -1232,9 +1207,6 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
     public void removeColumn(PName tenantId, String tableName,
             List<PColumn> columnsToRemove, long tableTimeStamp,
             long tableSeqNum, long resolvedTime) throws SQLException {
-        metaData.removeColumn(tenantId, tableName, columnsToRemove,
-                tableTimeStamp, tableSeqNum, resolvedTime);
-        // Cascade through to connectionQueryServices too
         getQueryServices().removeColumn(tenantId, tableName, columnsToRemove,
                 tableTimeStamp, tableSeqNum, resolvedTime);
     }
@@ -1253,7 +1225,7 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
      * {@link PreparedStatement}s that were created from this connection before
      * commit or rollback. 0-based. Used to associate partial save errors with
      * SQL statements invoked by users.
-     * 
+     *
      * @see CommitException
      * @see #incrementStatementExecutionCounter()
      */
@@ -1297,7 +1269,7 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
     /**
      * Returns true if this connection is being used to upgrade the data due to
      * PHOENIX-2067 and false otherwise.
-     * 
+     *
      * @return
      */
     public boolean isDescVarLengthRowKeyUpgrade() {
@@ -1344,8 +1316,6 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
 
     @Override
     public void removeSchema(PSchema schema, long schemaTimeStamp) {
-        metaData.removeSchema(schema, schemaTimeStamp);
-        // Cascade through to connectionQueryServices too
         getQueryServices().removeSchema(schema, schemaTimeStamp);
 
     }
@@ -1365,7 +1335,7 @@ public class PhoenixConnection implements Connection, MetaDataMutated, SQLClosea
     public LogLevel getAuditLogLevel(){
         return this.auditLogLevel;
     }
-    
+
     public Double getLogSamplingRate(){
         return this.logSamplingRate;
     }
