@@ -493,6 +493,10 @@ public class IndexTool extends Configured implements Tool {
                 }
                 if (useSnapshot || (!isLocalIndexBuild && pDataTable.isTransactional())) {
                     PhoenixConfigurationUtil.setCurrentScnValue(configuration, maxTimeRange);
+                    if (indexVerifyType != IndexVerifyType.NONE) {
+                        LOGGER.warn("Verification is not supported for snapshots and transactional"
+                                + "table index rebuilds, verification parameter ignored");
+                    }
                     return configureJobForAsyncIndex();
                 } else {
                     // Local and non-transactional global indexes to be built on the server side
@@ -571,7 +575,7 @@ public class IndexTool extends Configured implements Tool {
             if (pDataTable.isTransactional()) {
                 long maxTimeRange = pDataTable.getTimeStamp() + 1;
                 scan.setAttribute(BaseScannerRegionObserver.TX_SCN,
-                        Bytes.toBytes(Long.valueOf(Long.toString(TransactionUtil.convertToNanoseconds(maxTimeRange)))));
+                        Bytes.toBytes(TransactionUtil.convertToNanoseconds(maxTimeRange)));
             }
             
           
@@ -636,6 +640,7 @@ public class IndexTool extends Configured implements Tool {
 
             configuration.set(PhoenixConfigurationUtil.UPSERT_STATEMENT, upsertQuery);
             PhoenixConfigurationUtil.setPhysicalTableName(configuration, physicalIndexTable);
+            PhoenixConfigurationUtil.setIndexToolIndexTableName(configuration, qIndexTable);
             PhoenixConfigurationUtil.setDisableIndexes(configuration, indexTable);
 
             PhoenixConfigurationUtil.setUpsertColumnNames(configuration,
@@ -666,9 +671,14 @@ public class IndexTool extends Configured implements Tool {
                 String snapshotName;
                 try {
                     admin = pConnection.getQueryServices().getAdmin();
-                    String pdataTableName = pDataTable.getName().getString();
-                    snapshotName = new StringBuilder(pdataTableName).append("-Snapshot").toString();
-                    admin.snapshot(snapshotName, TableName.valueOf(pdataTableName));
+                    TableName hDdataTableName = TableName.valueOf(pDataTable.getPhysicalName().getBytes());
+                    snapshotName = new StringBuilder("INDEXTOOL-")
+                            .append(pDataTable.getName().getString())
+                            .append("-Snapshot-")
+                            .append(System.currentTimeMillis())
+                            .toString();
+                    //FIXME Drop this snapshot after we're done ?
+                    admin.snapshot(snapshotName, hDdataTableName);
                 } finally {
                     if (admin != null) {
                         admin.close();
@@ -972,6 +982,11 @@ public class IndexTool extends Configured implements Tool {
         qIndexTable = SchemaUtil.getQualifiedTableName(schemaName, indexTable);
         if (IndexType.LOCAL.equals(indexType)) {
             isLocalIndexBuild = true;
+            if (useSnapshot) {
+                throw new IllegalArgumentException(String.format(
+                    "%s is a local index. snapshots are not supported for local indexes.",
+                    qIndexTable));
+            }
             try (org.apache.hadoop.hbase.client.Connection hConn
                     = getTemporaryHConnection(connection.unwrap(PhoenixConnection.class))) {
                 RegionLocator regionLocator = hConn
@@ -1046,9 +1061,10 @@ public class IndexTool extends Configured implements Tool {
             throws SQLException, IOException, IllegalArgumentException {
         int numRegions;
 
+        TableName hDataName = TableName.valueOf(pDataTable.getPhysicalName().getBytes());
         try (org.apache.hadoop.hbase.client.Connection tempHConn = getTemporaryHConnection(pConnection);
                 RegionLocator regionLocator =
-                        tempHConn.getRegionLocator(TableName.valueOf(qDataTable))) {
+                        tempHConn.getRegionLocator(hDataName)) {
             numRegions = regionLocator.getStartKeys().length;
             if (autosplit && (numRegions <= autosplitNumRegions)) {
                 LOGGER.info(String.format(
@@ -1089,10 +1105,10 @@ public class IndexTool extends Configured implements Tool {
                 splitPoints[splitIdx++] = b.getRightBoundExclusive();
             }
             // drop table and recreate with appropriate splits
-            TableName indexTN = TableName.valueOf(pIndexTable.getPhysicalName().getBytes());
-            HTableDescriptor descriptor = admin.getTableDescriptor(indexTN);
-            admin.disableTable(indexTN);
-            admin.deleteTable(indexTN);
+            TableName hIndexName = TableName.valueOf(pIndexTable.getPhysicalName().getBytes());
+            HTableDescriptor descriptor = admin.getTableDescriptor(hIndexName);
+            admin.disableTable(hIndexName);
+            admin.deleteTable(hIndexName);
             admin.createTable(descriptor, splitPoints);
         }
     }
