@@ -18,6 +18,7 @@
 package org.apache.phoenix.mapreduce.index;
 
 import java.io.IOException;
+import java.nio.charset.StandardCharsets;
 import java.sql.SQLException;
 import java.util.List;
 import java.util.Properties;
@@ -164,8 +165,9 @@ public class PhoenixIndexPartialBuildMapper extends TableMapper<ImmutableBytesWr
             }
             // We are writing some dummy key-value as map output here so that we commit only one
             // output to reducer.
-            context.write(new ImmutableBytesWritable(UUID.randomUUID().toString().getBytes()),
-                new IntWritable(0));
+            context.write(new ImmutableBytesWritable(
+                    UUID.randomUUID().toString().getBytes(StandardCharsets.UTF_8)),
+                    new IntWritable(0));
             super.cleanup(context);
         } catch (SQLException e) {
             LOGGER.error(" Error {}  while read/write of a record ", e.getMessage());
