@@ -463,7 +463,7 @@ public final class PhoenixConfigurationUtil {
     public static int getMultiViewQueryMoreSplitSize(final Configuration configuration) {
         final String batchSize = configuration.get(MAPREDUCE_MULTI_INPUT_QUERY_BATCH_SIZE);
         Preconditions.checkNotNull(batchSize);
-        return Integer.valueOf(batchSize);
+        return Integer.parseInt(batchSize);
     }
 
     public static List<ColumnInfo> getSelectColumnMetadataList(final Configuration configuration) throws SQLException {
@@ -493,7 +493,7 @@ public final class PhoenixConfigurationUtil {
     public static int getMultiViewSplitSize(final Configuration configuration) {
         final String splitSize = configuration.get(MAPREDUCE_MULTI_INPUT_MAPPER_SPLIT_SIZE);
         Preconditions.checkNotNull(splitSize);
-        return Integer.valueOf(splitSize);
+        return Integer.parseInt(splitSize);
     }
 
     private static List<String> getSelectColumnList(
@@ -511,14 +511,16 @@ public final class PhoenixConfigurationUtil {
         Preconditions.checkNotNull(configuration);
         String selectStmt = configuration.get(SELECT_STATEMENT);
         if(isNotEmpty(selectStmt)) {
+            LOGGER.info("Select Statement: " + selectStmt);
             return selectStmt;
         }
         final String tableName = getInputTableName(configuration);
         Preconditions.checkNotNull(tableName);
         final List<ColumnInfo> columnMetadataList = getSelectColumnMetadataList(configuration);
         final String conditions = configuration.get(INPUT_TABLE_CONDITIONS);
+        LOGGER.info("Building select statement from input conditions: " + conditions);
         selectStmt = QueryUtil.constructSelectStatement(tableName, columnMetadataList, conditions);
-        LOGGER.info("Select Statement: "+ selectStmt);
+        LOGGER.info("Select Statement: " + selectStmt);
         configuration.set(SELECT_STATEMENT, selectStmt);
         return selectStmt;
     }
