@@ -19,6 +19,7 @@ package org.apache.phoenix.query;
 
 
 import java.math.BigDecimal;
+import java.nio.charset.StandardCharsets;
 
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
@@ -182,7 +183,6 @@ public interface QueryConstants {
     enum JoinType {INNER, LEFT_OUTER}
     String SYSTEM_SCHEMA_NAME = "SYSTEM";
     byte[] SYSTEM_SCHEMA_NAME_BYTES = Bytes.toBytes(SYSTEM_SCHEMA_NAME);
-    String HBASE_DEFAULT_SCHEMA_NAME = "default";
     String OFFSET_ROW_KEY = "_OFFSET_";
     byte[] OFFSET_ROW_KEY_BYTES = Bytes.toBytes(OFFSET_ROW_KEY);
     ImmutableBytesPtr OFFSET_ROW_KEY_PTR = new ImmutableBytesPtr(OFFSET_ROW_KEY_BYTES);
@@ -248,6 +248,14 @@ public interface QueryConstants {
     byte[] DEFAULT_COLUMN_FAMILY_BYTES = Bytes.toBytes(DEFAULT_COLUMN_FAMILY);
     ImmutableBytesPtr DEFAULT_COLUMN_FAMILY_BYTES_PTR = new ImmutableBytesPtr(
             DEFAULT_COLUMN_FAMILY_BYTES);
+
+    byte VERIFIED_BYTE = 1;
+    byte UNVERIFIED_BYTE = 2;
+    byte[] VERIFIED_BYTES = new byte[] { VERIFIED_BYTE };
+    byte[] UNVERIFIED_BYTES = new byte[] { UNVERIFIED_BYTE };
+    ImmutableBytesPtr VERIFIED_BYTES_PTR = new ImmutableBytesPtr(VERIFIED_BYTES);
+    ImmutableBytesPtr UNVERIFIED_BYTES_PTR = new ImmutableBytesPtr(UNVERIFIED_BYTES);
+
     // column qualifier of the single key value used to store all columns for the
     // COLUMNS_STORED_IN_SINGLE_CELL storage scheme
     String SINGLE_KEYVALUE_COLUMN_QUALIFIER = "1";
@@ -463,8 +471,8 @@ public interface QueryConstants {
             ImmutableStorageScheme.SINGLE_CELL_ARRAY_WITH_OFFSETS.name() + ",\n" +
             TableProperty.COLUMN_ENCODED_BYTES.toString()+" = 1";
     
-    byte[] OFFSET_FAMILY = "f_offset".getBytes();
-    byte[] OFFSET_COLUMN = "c_offset".getBytes();
+    byte[] OFFSET_FAMILY = "f_offset".getBytes(StandardCharsets.UTF_8);
+    byte[] OFFSET_COLUMN = "c_offset".getBytes(StandardCharsets.UTF_8);
     String LAST_SCAN = "LAST_SCAN";
     String HASH_JOIN_CACHE_RETRIES = "hashjoin.client.retries.number";
     int DEFAULT_HASH_JOIN_CACHE_RETRIES = 5;
