@@ -44,19 +44,21 @@ public class SystemCatalogWALEntryFilter implements
    * about cell filter for certain WALEdits.
    */
   private boolean skipCellFilter;
+  // Column value for parent child link
   private static final byte[] CHILD_TABLE_BYTES =
     new byte[]{PTable.LinkType.CHILD_TABLE.getSerializedValue()};
-  private final int NUM_COLUMNS_PRIMARY_KEY = 5;
+  // Number of columns in the primary key of system child link table
+  private static final int NUM_COLUMNS_PRIMARY_KEY = 5;
 
   @Override
   public WAL.Entry filter(WAL.Entry entry) {
     // We use the WALCellFilter to filter the cells from entry, WALEntryFilter
-    // should not block anything
-    // if the WAL.Entry's table isn't System.Catalog or System.Child_Link,
-    // it auto-passes this filter
+    // should not block anything.
+    // If the WAL.Entry's table isn't System.Catalog or System.Child_Link,
+    // it auto-passes this filter.
     skipCellFilter =
-      !(SchemaUtil.isMetaTable(entry.getKey().getTablename().getName())
-      || SchemaUtil.isChildLinkTable(entry.getKey().getTablename().getName()));
+      !(SchemaUtil.isMetaTable(entry.getKey().getTableName().getName())
+      || SchemaUtil.isChildLinkTable(entry.getKey().getTableName().getName()));
     return entry;
   }
 
@@ -66,19 +68,19 @@ public class SystemCatalogWALEntryFilter implements
       return cell;
     }
 
-    if (SchemaUtil.isMetaTable(entry.getKey().getTablename().getName())) {
-      return doesKeyHaveLeadingSeparatorByte(cell) ? cell : null;
+    if (SchemaUtil.isMetaTable(entry.getKey().getTableName().getName())) {
+      return isTenantIdLeadingInKey(cell) ? cell : null;
     } else {
       return isTenantRowCellSystemChildLink(cell) ? cell : null;
     }
   }
 
   /**
-   * does the cell key have leading separator byte
+   * Does the cell key have leading tenant Id.
    * @param cell hbase cell
-   * @return true if the cell has leading separator byte
+   * @return true if the cell has leading tenant Id in key
    */
-  private boolean doesKeyHaveLeadingSeparatorByte(final Cell cell) {
+  private boolean isTenantIdLeadingInKey(final Cell cell) {
     // rows in system.catalog or system child that aren't tenant-owned
     // will have a leading separator byte
     return cell.getRowArray()[cell.getRowOffset()]
@@ -90,12 +92,13 @@ public class SystemCatalogWALEntryFilter implements
    * tenant id, system.child_link table have tenant owned data for parent child
    * links. In this case, the column qualifier is
    * {@code PhoenixDatabaseMetaData#LINK_TYPE_BYTES} and value is
-   * {@code PTable.LinkType.CHILD_TABLE}.
+   * {@code PTable.LinkType.CHILD_TABLE}. For corresponding delete markers the
+   * KeyValue type {@code KeyValue.Type} is {@code KeyValue.Type.DeleteFamily}
    * @param cell hbase cell
    * @return true if the cell is tenant owned
    */
   private boolean isTenantRowCellSystemChildLink(final Cell cell) {
-    boolean isTenantRowCell = doesKeyHaveLeadingSeparatorByte(cell);
+    boolean isTenantRowCell = isTenantIdLeadingInKey(cell);
 
     ImmutableBytesWritable key = new ImmutableBytesWritable(
       cell.getRowArray(), cell.getRowOffset(), cell.getRowLength());
@@ -103,18 +106,18 @@ public class SystemCatalogWALEntryFilter implements
     if (!isTenantRowCell) {
       boolean isChildLink = CellUtil.matchingQualifier(
         cell, PhoenixDatabaseMetaData.LINK_TYPE_BYTES);
-      if (isChildLink) {
-        if (CellUtil.matchingValue(cell, CHILD_TABLE_BYTES)) {
-          byte[][] rowViewKeyMetadata = new byte[NUM_COLUMNS_PRIMARY_KEY][];
-          SchemaUtil.getVarChars(key.get(), key.getOffset(),
+      if ((isChildLink && CellUtil.matchingValue(cell, CHILD_TABLE_BYTES)) ||
+          CellUtil.isDeleteFamily(cell)) {
+        byte[][] rowViewKeyMetadata = new byte[NUM_COLUMNS_PRIMARY_KEY][];
+        SchemaUtil.getVarChars(key.get(), key.getOffset(),
             key.getLength(), 0, rowViewKeyMetadata);
-          // if the child link is to a tenant-owned view,
-          // the COLUMN_NAME field will be the byte[] of the tenant
-          //otherwise, it will be an empty byte array
-          // (NOT QueryConstants.SEPARATOR_BYTE, but a byte[0])
-          isChildLinkToTenantView =
-            rowViewKeyMetadata[COLUMN_NAME_INDEX].length != 0;
-        }
+        /** if the child link is to a tenant-owned view, the COLUMN_NAME field will be
+         * the byte[] of the tenant otherwise, it will be an empty byte array
+         * (NOT QueryConstants.SEPARATOR_BYTE, but a byte[0]). This assumption is also
+         * true for child link's delete markers in SYSTEM.CHILD_LINK as it only contains link
+         * rows and does not deal with other type of rows like column rows that also has
+         * COLUMN_NAME populated with actual column name.**/
+        isChildLinkToTenantView = rowViewKeyMetadata[COLUMN_NAME_INDEX].length != 0;
       }
     }
     return isTenantRowCell || isChildLinkToTenantView;
