@@ -59,7 +59,7 @@ import org.apache.phoenix.util.SchemaUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 
 /**
  * A default implementation of the Statistics tracker that helps to collect stats like min key, max key and guideposts.
@@ -156,9 +156,8 @@ public class DefaultStatisticsCollector implements StatisticsCollector {
                         configuration.getLong(
                                 QueryServices.STATS_GUIDEPOST_WIDTH_BYTES_ATTRIB,
                                 QueryServicesOptions.DEFAULT_STATS_GUIDEPOST_WIDTH_BYTES),
-                        region.getTableDesc());
-                LOGGER.info("Guide post depth determined from global configuration: " +
-                        guidePostDepth);
+                        region.getTableDescriptor());
+                LOGGER.info("Guide post depth determined from global configuration: " + guidePostDepth);
             }
         }
 
@@ -227,7 +226,7 @@ public class DefaultStatisticsCollector implements StatisticsCollector {
             guidepostWidth = PLong.INSTANCE.getCodec().decodeInt(guidePostWidthBytes, 0, SortOrder.getDefault());
         }
         this.guidePostDepth = StatisticsUtil.getGuidePostDepth(guidepostPerRegion, guidepostWidth,
-                region.getTableDesc());
+                region.getTableDescriptor());
     }
 
     @Override
@@ -270,7 +269,7 @@ public class DefaultStatisticsCollector implements StatisticsCollector {
                     !scan.getFamilyMap().isEmpty() &&
                     MetaDataUtil.isLocalIndexFamily(scan.getFamilyMap().keySet().iterator().next());
             for (Store store : region.getStores()) {
-                ImmutableBytesPtr cfKey = new ImmutableBytesPtr(store.getFamily().getName());
+                ImmutableBytesPtr cfKey = new ImmutableBytesPtr(store.getColumnFamilyDescriptor().getName());
                 boolean isLocalIndexStore = MetaDataUtil.isLocalIndexFamily(cfKey);
                 if (isLocalIndexStore != collectingForLocalIndex) {
                     continue;
@@ -306,7 +305,6 @@ public class DefaultStatisticsCollector implements StatisticsCollector {
      * 
      * @param results
      *            next batch of {@link KeyValue}s
-     * @throws IOException 
      */
     @Override
     public void collectStatistics(final List<Cell> results) {
@@ -328,12 +326,11 @@ public class DefaultStatisticsCollector implements StatisticsCollector {
             incrementRow = true;
         }
         for (Cell cell : results) {
-            KeyValue kv = KeyValueUtil.ensureKeyValue(cell);
-            maxTimeStamp = Math.max(maxTimeStamp, kv.getTimestamp());
+            maxTimeStamp = Math.max(maxTimeStamp, cell.getTimestamp());
             Pair<Long, GuidePostsInfoBuilder> gps;
             if (cachedGuidePosts == null) {
-                ImmutableBytesPtr cfKey = new ImmutableBytesPtr(kv.getFamilyArray(), kv.getFamilyOffset(),
-                        kv.getFamilyLength());
+                ImmutableBytesPtr cfKey = new ImmutableBytesPtr(cell.getFamilyArray(), cell.getFamilyOffset(),
+                        cell.getFamilyLength());
                 gps = guidePostsInfoWriterMap.get(cfKey);
                 if (gps == null) {
                     gps = new Pair<Long, GuidePostsInfoBuilder>(0l,
@@ -351,7 +348,7 @@ public class DefaultStatisticsCollector implements StatisticsCollector {
                     incrementRow = false;
                 }
             }
-            int kvLength = kv.getLength();
+            int kvLength = KeyValueUtil.getSerializedSize(cell, true);
             long byteCount = gps.getFirst() + kvLength;
             gps.setFirst(byteCount);
             if (byteCount >= guidePostDepth) {
@@ -387,7 +384,7 @@ public class DefaultStatisticsCollector implements StatisticsCollector {
                                                    Store store, InternalScanner delegate) {
 
         ImmutableBytesPtr cfKey =
-                new ImmutableBytesPtr(store.getFamily().getName());
+                new ImmutableBytesPtr(store.getColumnFamilyDescriptor().getName());
         LOGGER.info("StatisticsScanner created for table: "
                 + tableName + " CF: " + store.getColumnFamilyName());
         return new StatisticsScanner(this, statsWriter, env, delegate, cfKey);
