@@ -17,21 +17,20 @@
  */
 package org.apache.phoenix.schema.task;
 
-import com.google.common.base.Strings;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.client.coprocessor.Batch;
-import org.apache.hadoop.hbase.ipc.RpcServer;
-import org.apache.hadoop.hbase.ipc.RpcUtil;
-import org.apache.hadoop.hbase.security.User;
 import org.apache.hadoop.hbase.util.Pair;
 import org.apache.phoenix.coprocessor.MetaDataProtocol.MetaDataMutationResult;
 import org.apache.phoenix.coprocessor.generated.MetaDataProtos.MetaDataResponse;
 import org.apache.phoenix.coprocessor.generated.TaskMetaDataProtos
     .TaskMetaDataService;
-import org.apache.phoenix.coprocessor.tasks.DropChildViewsTask;
+import org.apache.phoenix.thirdparty.com.google.common.base.Strings;
+import org.apache.hadoop.hbase.ipc.RpcCall;
+import org.apache.hadoop.hbase.ipc.RpcUtil;
+import org.apache.hadoop.hbase.security.User;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.jdbc.PhoenixDatabaseMetaData;
 import org.apache.phoenix.schema.PTable;
@@ -55,16 +54,20 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 
+import edu.umd.cs.findbugs.annotations.SuppressWarnings;
+
+@SuppressWarnings(value="SQL_PREPARED_STATEMENT_GENERATED_FROM_NONCONSTANT_STRING",
+    justification="Not possible to avoid")
 public class Task {
     public static final Logger LOGGER = LoggerFactory.getLogger(Task.class);
-    private static void mutateSystemTaskTable(final PhoenixConnection conn, final PreparedStatement stmt, boolean accessCheckEnabled)
+    private static void mutateSystemTaskTable(PhoenixConnection conn, PreparedStatement stmt, boolean accessCheckEnabled)
             throws IOException {
         // we need to mutate SYSTEM.TASK with HBase/login user if access is enabled.
         if (accessCheckEnabled) {
             User.runAsLoginUser(new PrivilegedExceptionAction<Void>() {
                 @Override
                 public Void run() throws Exception {
-                    final RpcServer.Call rpcContext = RpcUtil.getRpcContext();
+                    final RpcCall rpcContext = RpcUtil.getRpcContext();
                     // setting RPC context as null so that user can be reset
                     try {
                         RpcUtil.setRpcContext(null);
@@ -91,24 +94,21 @@ public class Task {
     }
 
     private static List<Mutation> getMutationsForSystemTaskTable(
-            final PhoenixConnection conn, final PreparedStatement stmt,
-            final boolean accessCheckEnabled) throws IOException {
+            PhoenixConnection conn, PreparedStatement stmt,
+            boolean accessCheckEnabled) throws IOException {
         // we need to mutate SYSTEM.TASK with HBase/login user if access is enabled.
         if (accessCheckEnabled) {
-            return User.runAsLoginUser(new PrivilegedExceptionAction<List<Mutation>>() {
-                @Override
-                public List<Mutation> run() throws Exception {
-                    final RpcServer.Call rpcContext = RpcUtil.getRpcContext();
-                    // setting RPC context as null so that user can be reset
-                    try {
-                        RpcUtil.setRpcContext(null);
-                        return executeStatementAndGetTaskMutations(conn, stmt);
-                    } catch (SQLException e) {
-                        throw new IOException(e);
-                    } finally {
-                        // setting RPC context back to original context of the RPC
-                        RpcUtil.setRpcContext(rpcContext);
-                    }
+            return User.runAsLoginUser(() -> {
+                final RpcCall rpcContext = RpcUtil.getRpcContext();
+                // setting RPC context as null so that user can be reset
+                try {
+                    RpcUtil.setRpcContext(null);
+                    return executeStatementAndGetTaskMutations(conn, stmt);
+                } catch (SQLException e) {
+                    throw new IOException(e);
+                } finally {
+                    // setting RPC context back to original context of the RPC
+                    RpcUtil.setRpcContext(rpcContext);
                 }
             });
         } else {
@@ -189,7 +189,7 @@ public class Task {
      *     or committing transactions
      */
     public static void addTask(SystemTaskParams systemTaskParams)
-      throws IOException {
+            throws IOException {
         addTaskAndGetStatement(systemTaskParams, systemTaskParams.getConn(),
             true);
     }
@@ -218,12 +218,11 @@ public class Task {
                 systemTaskParams.getTaskStatus(), systemTaskParams.getData(),
                 systemTaskParams.getPriority(), systemTaskParams.getStartTs(),
                 systemTaskParams.getEndTs());
-            LOGGER.info("Adding task type: "
-                + systemTaskParams.getTaskType() + " , tableName: "
-                + systemTaskParams.getTableName() + " , taskStatus: "
-                + systemTaskParams.getTaskStatus() + " , startTs: "
-                + systemTaskParams.getStartTs() + " , endTs: "
-                + systemTaskParams.getEndTs());
+            LOGGER.info("Adding task type: {} , tableName: {} , taskStatus: {}"
+                + " , startTs: {} , endTs: {}", systemTaskParams.getTaskType(),
+                systemTaskParams.getTableName(),
+                systemTaskParams.getTaskStatus(), systemTaskParams.getStartTs(),
+                systemTaskParams.getEndTs());
         } catch (SQLException e) {
             throw new IOException(e);
         }
@@ -268,8 +267,8 @@ public class Task {
             final Batch.Call<TaskMetaDataService, MetaDataResponse> callable)
             throws SQLException {
         TableName tableName = SchemaUtil.getPhysicalName(
-              PhoenixDatabaseMetaData.SYSTEM_TASK_NAME_BYTES,
-              connection.getQueryServices().getProps());
+            PhoenixDatabaseMetaData.SYSTEM_TASK_NAME_BYTES,
+            connection.getQueryServices().getProps());
         try (Table table =
                 connection.getQueryServices().getTable(tableName.getName())) {
             final Map<byte[], MetaDataResponse> results =
