@@ -18,20 +18,31 @@
 package org.apache.phoenix.transaction;
 
 import java.io.IOException;
-import java.util.List;
 
+import org.apache.hadoop.hbase.util.VersionInfo;
 import org.apache.phoenix.coprocessor.MetaDataProtocol;
 
 public class TransactionFactory {
 
-    private static PhoenixTransactionProvider tephraTransactionProvider;
+    private static final PhoenixTransactionProvider tephraTransactionProvider;
 
     static{
-        try {
-            tephraTransactionProvider = (PhoenixTransactionProvider)
-                    Class.forName("org.apache.phoenix.transaction.TephraTransactionProvider")
-                    .newInstance();
-        } catch (Throwable e) {
+        boolean tephraEnabled = true;
+        //FIXME this may break with vendor version numbers
+        if(VersionInfo.compareVersion(VersionInfo.getVersion(), "2.4") > 0) {
+            //Tephra does not support Hbase 2.5 or later
+            tephraEnabled = false;
+        } else {
+            try {
+                //Tephra not linked in
+                Class.forName("org.apache.tephra.TransactionFailureException");
+            } catch (Throwable e) {
+                tephraEnabled = false;
+            }
+        }
+        if (tephraEnabled) {
+            tephraTransactionProvider = TephraTransactionProvider.getInstance();
+        } else {
             tephraTransactionProvider = NotAvailableTransactionProvider.getInstance();
         }
     }
