@@ -22,9 +22,26 @@ import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.FAMILY_NAME_INDEX;
 import static org.apache.phoenix.util.SchemaUtil.getVarChars;
 
 import java.io.IOException;
+import java.nio.charset.StandardCharsets;
 import java.sql.SQLException;
 import java.util.*;
 
+import org.apache.phoenix.schema.ColumnFamilyNotFoundException;
+import org.apache.phoenix.schema.ColumnNotFoundException;
+import org.apache.phoenix.schema.PColumn;
+import org.apache.phoenix.schema.PColumnFamily;
+import org.apache.phoenix.schema.PName;
+import org.apache.phoenix.schema.PNameFactory;
+import org.apache.phoenix.schema.PTable;
+import org.apache.phoenix.schema.PTableType;
+import org.apache.phoenix.schema.SequenceKey;
+import org.apache.phoenix.schema.SortOrder;
+import org.apache.phoenix.schema.TableNotFoundException;
+import org.apache.phoenix.schema.TableProperty;
+import org.apache.phoenix.schema.types.PChar;
+import org.apache.phoenix.schema.types.PTinyint;
+import org.apache.phoenix.schema.types.PVarbinary;
+import org.apache.phoenix.schema.types.PVarchar;
 import org.apache.phoenix.thirdparty.com.google.common.annotations.VisibleForTesting;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Cell;
@@ -63,7 +80,6 @@ import org.apache.phoenix.hbase.index.util.VersionUtil;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.jdbc.PhoenixDatabaseMetaData;
 import org.apache.phoenix.query.QueryConstants;
-import org.apache.phoenix.schema.*;
 import org.apache.phoenix.schema.PTable.IndexType;
 import org.apache.phoenix.schema.PTable.LinkType;
 import org.apache.phoenix.schema.PTable.ViewType;
@@ -73,6 +89,7 @@ import org.apache.phoenix.schema.types.PInteger;
 import org.apache.phoenix.schema.types.PLong;
 import org.apache.phoenix.schema.types.PSmallint;
 import org.apache.phoenix.schema.types.PUnsignedTinyint;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableMap;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -100,6 +117,11 @@ public class MetaDataUtil {
 
     public static final byte[] DATA_TABLE_NAME_PROP_BYTES = Bytes.toBytes(DATA_TABLE_NAME_PROP_NAME);
 
+    private static final Map<MajorMinorVersion, MajorMinorVersion> ALLOWED_SERVER_CLIENT_MAJOR_VERSION =
+            ImmutableMap.of(
+                    new MajorMinorVersion(5, 1), new MajorMinorVersion(4, 16)
+            );
+
     // See PHOENIX-3955
     public static final List<String> SYNCED_DATA_TABLE_AND_INDEX_COL_FAM_PROPERTIES = ImmutableList.of(
             ColumnFamilyDescriptorBuilder.TTL,
@@ -176,13 +198,22 @@ public class MetaDataUtil {
             compatibility.setCompatible(false);
             return compatibility;
         } else if (VersionUtil.encodeMaxMinorVersion(clientMajorVersion) < serverVersion) { // Client major version must at least be up to server major version
-            compatibility.setErrorCode(SQLExceptionCode.INCOMPATIBLE_CLIENT_SERVER_JAR.getErrorCode());
-            compatibility.setCompatible(false);
-            return compatibility;
+            MajorMinorVersion serverMajorMinorVersion = new MajorMinorVersion(
+                    VersionUtil.decodeMajorVersion(serverVersion),
+                    VersionUtil.decodeMinorVersion(serverVersion));
+            MajorMinorVersion clientMajorMinorVersion =
+                    new MajorMinorVersion(clientMajorVersion, clientMinorVersion);
+            if (!clientMajorMinorVersion.equals(
+                    ALLOWED_SERVER_CLIENT_MAJOR_VERSION.get(serverMajorMinorVersion))) {
+                // Incompatible if not whitelisted by ALLOWED_SERVER_CLIENT_MAJOR_VERSION
+                compatibility.setErrorCode(SQLExceptionCode
+                        .INCOMPATIBLE_CLIENT_SERVER_JAR.getErrorCode());
+                compatibility.setCompatible(false);
+                return compatibility;
+            }
         }
         compatibility.setCompatible(true);
         return compatibility;
-
     }
 
     // Given the encoded integer representing the phoenix version in the encoded version value.
@@ -225,8 +256,10 @@ public class MetaDataUtil {
         return ((int)((version << Byte.SIZE * 3) >>> Byte.SIZE * 7) & 0x1) != 0;
     }
 
-    // The first 3 bytes of the long is used to encoding the HBase version as major.minor.patch.
-    // The next 4 bytes of the value is used to encode the Phoenix version as major.minor.patch.
+    // The first three bytes of the long encode the HBase version as major.minor.patch.
+    // The fourth byte is isTableNamespaceMappingEnabled
+    // The fifth to seventh bytes of the value encode the Phoenix version as major.minor.patch.
+    // The eights byte encodes whether the WAL codec is correctly installed
     /**
      * Encode HBase and Phoenix version along with some server-side config information such as whether WAL codec is
      * installed (necessary for non transactional, mutable secondar indexing), and whether systemNamespace mapping is enabled.
@@ -245,7 +278,9 @@ public class MetaDataUtil {
         long version =
         // Encode HBase major, minor, patch version
         (hbaseVersion << (Byte.SIZE * 5))
-                // Encode if systemMappingEnabled are enabled on the server side
+                // Encode if table namespace mapping is enabled on the server side
+                // Note that we DO NOT return information on whether system tables are mapped
+                // on the server side
                 | (isTableNamespaceMappingEnabled << (Byte.SIZE * 4))
                 // Encode Phoenix major, minor, patch version
                 | (phoenixVersion << (Byte.SIZE * 1))
@@ -750,7 +785,9 @@ public class MetaDataUtil {
     public static boolean hasLocalIndexTable(PhoenixConnection connection, byte[] physicalTableName) throws SQLException {
         try {
             TableDescriptor desc = connection.getQueryServices().getTableDescriptor(physicalTableName);
-            if(desc == null ) return false;
+            if (desc == null ) {
+                return false;
+            }
             return hasLocalIndexColumnFamily(desc);
         } catch (TableNotFoundException e) {
             return false;
@@ -778,7 +815,9 @@ public class MetaDataUtil {
 
     public static List<byte[]> getLocalIndexColumnFamilies(PhoenixConnection conn, byte[] physicalTableName) throws SQLException {
         TableDescriptor desc = conn.getQueryServices().getTableDescriptor(physicalTableName);
-        if(desc == null ) return Collections.emptyList();
+        if (desc == null ) {
+            return Collections.emptyList();
+        }
         List<byte[]> families = new ArrayList<byte[]>(desc.getColumnFamilies().length / 2);
         for (ColumnFamilyDescriptor cf : desc.getColumnFamilies()) {
             if (cf.getNameAsString().startsWith(QueryConstants.LOCAL_INDEX_COLUMN_FAMILY_PREFIX)) {
@@ -792,11 +831,11 @@ public class MetaDataUtil {
             throws SQLException {
         String schemaName = getViewIndexSequenceSchemaName(name, isNamespaceMapped);
         String sequenceName = getViewIndexSequenceName(name, null, isNamespaceMapped);
-        connection.createStatement().executeUpdate("DELETE FROM " + PhoenixDatabaseMetaData.SYSTEM_SEQUENCE + " WHERE "
-                + PhoenixDatabaseMetaData.SEQUENCE_SCHEMA
-                + (schemaName.length() > 0 ? "='" + schemaName + "'" : " IS NULL") + (isNamespaceMapped
-                        ? " AND " + PhoenixDatabaseMetaData.SEQUENCE_NAME + " = '" + sequenceName + "'" : ""));
-
+        connection.createStatement().executeUpdate("DELETE FROM "
+                + PhoenixDatabaseMetaData.SYSTEM_SEQUENCE
+                + " WHERE " + PhoenixDatabaseMetaData.SEQUENCE_SCHEMA
+                + (schemaName.length() > 0 ? "='" + schemaName + "'" : " IS NULL")
+                + " AND " + PhoenixDatabaseMetaData.SEQUENCE_NAME + " = '" + sequenceName + "'" );
     }
     
     /**
@@ -1001,7 +1040,8 @@ public class MetaDataUtil {
                 family.getPColumnForColumnNameBytes(rowKeyMetaData[PhoenixDatabaseMetaData.COLUMN_NAME_INDEX]);
         } else if (pkCount > COLUMN_NAME_INDEX
             && rowKeyMetaData[PhoenixDatabaseMetaData.COLUMN_NAME_INDEX].length > 0) {
-            col = table.getPKColumn(new String(rowKeyMetaData[PhoenixDatabaseMetaData.COLUMN_NAME_INDEX]));
+            col = table.getPKColumn(new String(
+                rowKeyMetaData[PhoenixDatabaseMetaData.COLUMN_NAME_INDEX], StandardCharsets.UTF_8));
         }
         return col;
     }
@@ -1014,21 +1054,20 @@ public class MetaDataUtil {
         try {
             connection.setAutoCommit(true);
             Set<String> physicalTablesSet = new HashSet<>();
-            Set<String> columnFamilies  = new HashSet<>();
             physicalTablesSet.add(table.getPhysicalName().getString());
-            for(byte[] physicalTableName:physicalTableNames) {
+            for (byte[] physicalTableName:physicalTableNames) {
                 physicalTablesSet.add(Bytes.toString(physicalTableName));
             }
-            for(MetaDataProtocol.SharedTableState s: sharedTableStates) {
+            for (MetaDataProtocol.SharedTableState s: sharedTableStates) {
                 physicalTablesSet.add(s.getPhysicalNames().get(0).getString());
             }
             StringBuilder buf = new StringBuilder("DELETE FROM SYSTEM.STATS WHERE PHYSICAL_NAME IN (");
             Iterator itr = physicalTablesSet.iterator();
-            while(itr.hasNext()) {
+            while (itr.hasNext()) {
                 buf.append("'" + itr.next() + "',");
             }
             buf.setCharAt(buf.length() - 1, ')');
-            if(table.getIndexType()==IndexType.LOCAL) {
+            if (table.getIndexType()==IndexType.LOCAL) {
                 buf.append(" AND COLUMN_FAMILY IN(");
                 if (table.getColumnFamilies().isEmpty()) {
                     buf.append("'" + QueryConstants.DEFAULT_LOCAL_INDEX_COLUMN_FAMILY + "',");
