@@ -133,9 +133,20 @@ public class ScanUtil {
         scan.setAttribute(BaseScannerRegionObserver.LOCAL_INDEX, PDataType.TRUE_BYTES);
     }
 
+    public static void setUncoveredGlobalIndex(Scan scan) {
+        scan.setAttribute(BaseScannerRegionObserver.UNCOVERED_GLOBAL_INDEX, PDataType.TRUE_BYTES);
+    }
+
     public static boolean isLocalIndex(Scan scan) {
         return scan.getAttribute(BaseScannerRegionObserver.LOCAL_INDEX) != null;
     }
+    public static boolean isUncoveredGlobalIndex(Scan scan) {
+        return scan.getAttribute(BaseScannerRegionObserver.UNCOVERED_GLOBAL_INDEX) != null;
+    }
+
+    public static boolean isLocalOrUncoveredGlobalIndex(Scan scan) {
+        return isLocalIndex(scan) || isUncoveredGlobalIndex(scan);
+    }
 
     public static boolean isNonAggregateScan(Scan scan) {
         return scan.getAttribute(BaseScannerRegionObserver.NON_AGGREGATE_QUERY) != null;
@@ -363,10 +374,12 @@ public class ScanUtil {
         }
         int[] position = new int[slots.size()];
         int maxLength = 0;
+        int slotEndingFieldPos = -1;
         for (int i = 0; i < position.length; i++) {
             position[i] = bound == Bound.LOWER ? 0 : slots.get(i).size()-1;
             KeyRange range = slots.get(i).get(position[i]);
-            Field field = schema.getField(i + slotSpan[i]);
+            slotEndingFieldPos = slotEndingFieldPos + slotSpan[i] + 1;
+            Field field = schema.getField(slotEndingFieldPos);
             int keyLength = range.getRange(bound).length;
             if (!field.getDataType().isFixedWidth()) {
                 keyLength++;
