@@ -29,6 +29,7 @@ import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.TABLE_FAMILY_BYTES
 import static org.apache.phoenix.query.QueryConstants.SEPARATOR_BYTE;
 import static org.apache.phoenix.query.QueryConstants.SEPARATOR_BYTE_ARRAY;
 
+import java.nio.charset.StandardCharsets;
 import java.sql.Connection;
 import java.sql.DatabaseMetaData;
 import java.sql.ResultSet;
@@ -37,6 +38,7 @@ import java.sql.SQLException;
 import java.sql.Statement;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.LinkedHashSet;
@@ -98,6 +100,7 @@ import org.apache.phoenix.thirdparty.com.google.common.base.Preconditions;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Iterables;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.base.Strings;
 
 /**
  * 
@@ -140,10 +143,11 @@ public class SchemaUtil {
         
     };
     public static final RowKeySchema VAR_BINARY_SCHEMA = new RowKeySchemaBuilder(1).addField(VAR_BINARY_DATUM, false, SortOrder.getDefault()).build();
-    public static final String SCHEMA_FOR_DEFAULT_NAMESPACE = "DEFAULT";
-    public static final String HBASE_NAMESPACE = "HBASE";
-    public static final List<String> NOT_ALLOWED_SCHEMA_LIST = Arrays.asList(SCHEMA_FOR_DEFAULT_NAMESPACE,
-            HBASE_NAMESPACE);
+    // See PHOENIX-4424
+    public static final String SCHEMA_FOR_DEFAULT_NAMESPACE = "default";
+    public static final String HBASE_NAMESPACE = "hbase";
+    public static final List<String> NOT_ALLOWED_SCHEMA_LIST = Collections.unmodifiableList(
+        Arrays.asList(SCHEMA_FOR_DEFAULT_NAMESPACE, HBASE_NAMESPACE));
     
     /**
      * May not be instantiated
@@ -260,7 +264,7 @@ public class SchemaUtil {
         return name != null && name.length() > 0 && name.charAt(0) == '"' && name.indexOf("\"", 1) == name.length() - 1;
     }
 
-    public static <T> List<T> concat(List<T> l1, List<T> l2) {
+    public static <T> Set<T> concat(Set<T> l1, Set<T> l2) {
         int size1 = l1.size();
         if (size1 == 0) {
             return l2;
@@ -269,7 +273,7 @@ public class SchemaUtil {
         if (size2 == 0) {
             return l1;
         }
-        List<T> l3 = new ArrayList<T>(size1 + size2);
+        Set<T> l3 = new LinkedHashSet<T>(size1 + size2);
         l3.addAll(l1);
         l3.addAll(l2);
         return l3;
@@ -667,7 +671,7 @@ public class SchemaUtil {
         if (schemaName == null || schemaName.length() == 0) {
             return "\"" + tableName + "\"";
         }
-        return "\"" + schemaName + "\"." + "\"" + tableName + "\"";
+        return "\"" + schemaName + "\"" + QueryConstants.NAME_SEPARATOR + "\"" + tableName + "\"";
     }
 
     protected static PhoenixConnection addMetaDataColumn(PhoenixConnection conn, long scn, String columnDef) throws SQLException {
@@ -1130,7 +1134,8 @@ public class SchemaUtil {
 
     public static byte[] getParentTableNameFromIndexTable(byte[] physicalTableName, String indexPrefix) {
         String tableName = Bytes.toString(physicalTableName);
-        return getParentTableNameFromIndexTable(tableName, indexPrefix).getBytes();
+        return getParentTableNameFromIndexTable(tableName, indexPrefix)
+                .getBytes(StandardCharsets.UTF_8);
     }
 
     public static String getParentTableNameFromIndexTable(String physicalTableName, String indexPrefix) {
@@ -1232,6 +1237,101 @@ public class SchemaUtil {
         return columnParseNode.getName();
     }
 
+    public static String getFullTableNameWithQuotes(String schemaName, String tableName,
+    boolean schemaNameCaseSensitive, boolean tableNameCaseSensitive) {
+        String fullTableName;
+
+        if (tableNameCaseSensitive) {
+            fullTableName = "\"" + tableName + "\"";
+        } else {
+            fullTableName = tableName;
+        }
+
+        if(schemaName != null && schemaName.length() != 0) {
+            if (schemaNameCaseSensitive) {
+                fullTableName = "\"" + schemaName + "\"" + QueryConstants.NAME_SEPARATOR + fullTableName;
+            } else {
+                fullTableName = schemaName + QueryConstants.NAME_SEPARATOR + fullTableName;
+            }
+        }
+        return fullTableName;
+    }
+
+    public static String getFullTableNameWithQuotes(String schemaName, String tableName) {
+        return getFullTableNameWithQuotes(schemaName, tableName,
+                quotesNeededForSchema(schemaName), quotesNeededForTable(tableName));
+    }
+
+    private static boolean quotesNeededForSchema(String name) {
+        if (Strings.isNullOrEmpty(name) || name.equals(QueryConstants.DEFAULT_COLUMN_FAMILY)) {
+            return false;
+        }
+        return quotesNeededForTable(name);
+    }
+
+    private static boolean quotesNeededForColumn(String name) {
+        if (!name.equals("_INDEX_ID") && name.startsWith("_")) {
+            return true;
+        }
+        return isQuotesNeeded(name) || containsLowerCase(name);
+    }
+
+    private static boolean quotesNeededForTable(String name) {
+        if (name.startsWith("_")) {
+            return true;
+        }
+        return isQuotesNeeded(name) || containsLowerCase(name);
+    }
+
+    public static String formatSchemaName(String name) {
+        if (quotesNeededForSchema(name)) {
+            name = "\"" + name + "\"";
+        }
+        return name;
+    }
+
+    public static String formatColumnName(String name) {
+        if (quotesNeededForColumn(name)) {
+            name = "\"" + name + "\"";
+        }
+        return name;
+    }
+
+    public static String formatIndexColumnName(String name) {
+        String[] splitName = name.split("\\.");
+        if(splitName.length < 2) {
+            if (!name.contains("\"")) {
+                if (quotesNeededForColumn(name)) {
+                    name = "\"" + name + "\"";
+                }
+                return name;
+            } else if (name.startsWith("\"") && name.endsWith("\"")) {
+                if (quotesNeededForColumn(name.substring(1, name.length() - 1))) {
+                    return name;
+                } else {
+                    return name.substring(1, name.length() - 1);
+                }
+            } else {
+                return name;
+            }
+        } else {
+            return String.format("%s.%s", formatIndexColumnName(splitName[0]),
+                    formatIndexColumnName(splitName[1]));
+        }
+    }
+
+    public static boolean containsLowerCase(String name) {
+        if (Strings.isNullOrEmpty(name)) {
+            return false;
+        }
+        for (int i=0; i<name.toCharArray().length; i++) {
+            char charAtI = name.charAt(i);
+            if (Character.isLowerCase(charAtI)){
+                return true;
+            }
+        }
+        return false;
+    }
 
     /**
      * This function is needed so that SchemaExtractionTool returns a valid DDL with correct
@@ -1253,15 +1353,21 @@ public class SchemaUtil {
             pTableName = "\""+pTableName+"\"";
         }
         if(tableNameNeedsQuotes || schemaNameNeedsQuotes) {
-            pTableFullName = pSchemaName + "." + pTableName;
+            if (!Strings.isNullOrEmpty(pSchemaName)) {
+                return String.format("%s.%s", pSchemaName, pTableName);
+            } else {
+                return pTableName;
+            }
         }
-
         return pTableFullName;
     }
 
     private static boolean isQuotesNeeded(String name) {
         // first char numeric or non-underscore
-        if(!Character.isAlphabetic(name.charAt(0)) && name.charAt(0)!='_') {
+        if (Strings.isNullOrEmpty(name)) {
+            return false;
+        }
+        if (!Character.isAlphabetic(name.charAt(0)) && name.charAt(0)!='_') {
             return true;
         }
         // for all other chars
