@@ -41,13 +41,21 @@ public class StringUtil {
     public final static char SINGLE_CHAR_LIKE = '_';
     public final static char MULTI_CHAR_WILDCARD = '*';
     public final static char MULTI_CHAR_LIKE = '%';
-    public final static String[] LIKE_ESCAPE_SEQS = new String[]{"\\"+SINGLE_CHAR_LIKE, "\\"+MULTI_CHAR_LIKE};
-    public final static String[] LIKE_UNESCAPED_SEQS = new String[]{""+SINGLE_CHAR_LIKE, ""+MULTI_CHAR_LIKE};
+    private final static String[] LIKE_ESCAPE_SEQS = new String[]{"\\"+SINGLE_CHAR_LIKE, "\\"+MULTI_CHAR_LIKE};
+    private final static String[] LIKE_UNESCAPED_SEQS = new String[]{""+SINGLE_CHAR_LIKE, ""+MULTI_CHAR_LIKE};
     
 
     private StringUtil() {
     }
 
+    public static final String[] getLikeEscapeSeqs() {
+        return Arrays.copyOf(LIKE_ESCAPE_SEQS, LIKE_ESCAPE_SEQS.length);
+    }
+
+    public static final String[] getLikeUnescapedSeqs() {
+        return Arrays.copyOf(LIKE_UNESCAPED_SEQS, LIKE_UNESCAPED_SEQS.length);
+    }
+
     /** Replace instances of character ch in String value with String replacement */
     public static String replaceChar(String value, char ch, CharSequence replacement) {
         if (value == null)
