@@ -86,7 +86,7 @@ import org.apache.phoenix.util.TestUtil;
 import org.junit.Ignore;
 import org.junit.Test;
 
-import com.google.common.collect.ImmutableList;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableList;
 
 
 public class WhereCompilerTest extends BaseConnectionlessQueryTest {
