@@ -50,6 +50,8 @@ import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
 import org.apache.hadoop.hbase.client.Connection;
 import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.client.Table;
+import org.apache.hadoop.hbase.HRegionInfo;
+import org.apache.hadoop.hbase.HRegionLocation;
 import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.phoenix.SystemExitRule;
@@ -157,6 +159,64 @@ public class ConnectionQueryServicesImplTest {
         }
     }
 
+    @Test
+    public void testGetNextRegionStartKey() {
+        HRegionInfo mockHRegionInfo = org.mockito.Mockito.mock(HRegionInfo.class);
+        HRegionLocation mockRegionLocation = org.mockito.Mockito.mock(HRegionLocation.class);
+        ConnectionQueryServicesImpl mockCqsi = org.mockito.Mockito.mock(ConnectionQueryServicesImpl.class,
+                org.mockito.Mockito.CALLS_REAL_METHODS);
+        byte[] corruptedStartAndEndKey = "0x3000".getBytes();
+        byte[] corruptedDecreasingKey = "0x2999".getBytes();
+        byte[] notCorruptedStartKey = "0x2999".getBytes();
+        byte[] notCorruptedEndKey = "0x3000".getBytes();
+        byte[] notCorruptedNewKey = "0x3001".getBytes();
+        byte[] mockTableName = "dummyTable".getBytes();
+        when(mockRegionLocation.getRegionInfo()).thenReturn(mockHRegionInfo);
+        when(mockHRegionInfo.getRegionName()).thenReturn(mockTableName);
+
+        // comparing the current regionInfo endKey is equal to the previous endKey
+        // [0x3000, Ox3000) vs 0x3000
+        when(mockHRegionInfo.getStartKey()).thenReturn(corruptedStartAndEndKey);
+        when(mockHRegionInfo.getEndKey()).thenReturn(corruptedStartAndEndKey);
+        testGetNextRegionStartKey(mockCqsi, mockRegionLocation, corruptedStartAndEndKey, true);
+
+        // comparing the current regionInfo endKey is less than previous endKey
+        // [0x3000,0x2999) vs 0x3000
+        when(mockHRegionInfo.getStartKey()).thenReturn(corruptedStartAndEndKey);
+        when(mockHRegionInfo.getEndKey()).thenReturn(corruptedDecreasingKey);
+        testGetNextRegionStartKey(mockCqsi, mockRegionLocation, corruptedStartAndEndKey, true);
+
+        // comparing the current regionInfo endKey is greater than the previous endKey
+        // [0x3000,0x3000) vs 0x3001
+        when(mockHRegionInfo.getStartKey()).thenReturn(notCorruptedStartKey);
+        when(mockHRegionInfo.getEndKey()).thenReturn(notCorruptedNewKey);
+        testGetNextRegionStartKey(mockCqsi, mockRegionLocation, notCorruptedEndKey, false);
+
+        // test EMPTY_START_ROW
+        when(mockHRegionInfo.getStartKey()).thenReturn(HConstants.EMPTY_START_ROW);
+        when(mockHRegionInfo.getEndKey()).thenReturn(notCorruptedEndKey);
+        testGetNextRegionStartKey(mockCqsi, mockRegionLocation, HConstants.EMPTY_START_ROW, false);
+
+        //test EMPTY_END_ROW
+        when(mockHRegionInfo.getStartKey()).thenReturn(notCorruptedStartKey);
+        when(mockHRegionInfo.getEndKey()).thenReturn(HConstants.EMPTY_END_ROW);
+        testGetNextRegionStartKey(mockCqsi, mockRegionLocation, notCorruptedStartKey, false);
+    }
+
+    private void testGetNextRegionStartKey(ConnectionQueryServicesImpl mockCqsi,
+                                           HRegionLocation mockRegionLocation, byte[] key, boolean isCorrupted) {
+        try {
+            mockCqsi.getNextRegionStartKey(mockRegionLocation, key);
+            if (isCorrupted) {
+                fail();
+            }
+        } catch (IOException e) {
+            if (!isCorrupted) {
+                fail();
+            }
+        }
+    }
+
     @Test
     public void testSysMutexCheckReturnsFalseWhenTableAbsent() throws Exception {
         // Override the getDescriptor() call to throw instead
