@@ -33,8 +33,9 @@ import java.util.ListIterator;
 import java.util.NoSuchElementException;
 
 import org.apache.hadoop.hbase.Cell;
-import org.apache.hadoop.hbase.KeyValue;
+import org.apache.hadoop.hbase.KeyValueUtil;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.phoenix.compat.hbase.test.DelegateCell;
 import org.apache.phoenix.schema.tuple.EncodedColumnQualiferCellsList;
 import org.junit.Test;
 
@@ -122,7 +123,7 @@ public class EncodedColumnQualifierCellsListTest {
         for (Cell c : cells) {
             assertTrue(list.contains(c));
         }
-        assertFalse(list.contains(KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(13))));
+        assertFalse(list.contains(KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(13))));
     }
     
     @Test
@@ -154,7 +155,7 @@ public class EncodedColumnQualifierCellsListTest {
         assertEquals(5, list.size());
         assertTrue(list.remove(cells[3]));
         assertEquals(4, list.size());
-        assertFalse(list.remove(KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(13))));
+        assertFalse(list.remove(KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(13))));
         assertEquals(4, list.size());
     }
     
@@ -165,10 +166,10 @@ public class EncodedColumnQualifierCellsListTest {
         EncodedColumnQualiferCellsList list2 = new EncodedColumnQualiferCellsList(11, 16, FOUR_BYTE_QUALIFIERS);
         populateList(list2);
         assertTrue(list1.containsAll(list2));
-        list2.remove(KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(11)));
+        list2.remove(KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(11)));
         assertTrue(list1.containsAll(list2));
         assertFalse(list2.containsAll(list1));
-        list2.add(KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(13)));
+        list2.add(KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(13)));
         assertFalse(list1.containsAll(list2));
         assertFalse(list2.containsAll(list1));
         List<Cell> arrayList = new ArrayList<>();
@@ -218,7 +219,7 @@ public class EncodedColumnQualifierCellsListTest {
         populateList(list2);
         // retainAll won't be modifying the list1 since they both have the same elements equality wise
         assertFalse(list1.retainAll(list2));
-        list2.remove(KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(12)));
+        list2.remove(KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(12)));
         assertTrue(list1.retainAll(list2));
         assertEquals(list1.size(), list2.size());
         for (Cell c : list1) {
@@ -408,7 +409,7 @@ public class EncodedColumnQualifierCellsListTest {
             i++;
             try {
                 itr.next();
-                list.add(KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(0)));
+                list.add(KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(0)));
                 if (i == 2) {
                     fail("ConcurrentModificationException should have been thrown as the list is being modified while being iterated through");
                 }
@@ -426,7 +427,7 @@ public class EncodedColumnQualifierCellsListTest {
         populateList(list);
         ListIterator<Cell> itr = list.listIterator();
         itr.next();
-        list.add(KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(0)));
+        list.add(KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(0)));
         try {
             itr.next();
             fail("ConcurrentModificationException should have been thrown as the list was modified without using iterator");
@@ -440,7 +441,7 @@ public class EncodedColumnQualifierCellsListTest {
         itr.next();
         itr.remove();
         itr.next();
-        list.remove(KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(0)));
+        list.remove(KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(0)));
         try {
             itr.next();
             fail("ConcurrentModificationException should have been thrown as the list was modified without using iterator");
@@ -451,158 +452,27 @@ public class EncodedColumnQualifierCellsListTest {
     
     private void populateListAndArray(List<Cell> list, Cell[] cells) {
         // add elements in reserved range
-        list.add(cells[0] = KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(0)));
-        list.add(cells[1] = KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(5)));
-        list.add(cells[2] = KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(10)));
+        list.add(cells[0] = KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(0)));
+        list.add(cells[1] = KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(5)));
+        list.add(cells[2] = KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(10)));
 
         // add elements in qualifier range
-        list.add(cells[6] = KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(16)));
-        list.add(cells[4] = KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(12)));
-        list.add(cells[5] = KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(14)));
-        list.add(cells[3] = KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(11)));
+        list.add(cells[6] = KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(16)));
+        list.add(cells[4] = KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(12)));
+        list.add(cells[5] = KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(14)));
+        list.add(cells[3] = KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(11)));
     }
 
     private void populateList(List<Cell> list) {
         // add elements in reserved range
-        list.add(KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(0)));
-        list.add(KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(5)));
-        list.add(KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(10)));
+        list.add(KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(0)));
+        list.add(KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(5)));
+        list.add(KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(10)));
 
         // add elements in qualifier range
-        list.add(KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(16)));
-        list.add(KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(12)));
-        list.add(KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(14)));
-        list.add(KeyValue.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(11)));
+        list.add(KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(16)));
+        list.add(KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(12)));
+        list.add(KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(14)));
+        list.add(KeyValueUtil.createFirstOnRow(row, cf, FOUR_BYTE_QUALIFIERS.encode(11)));
     }
-    
-    private class DelegateCell implements Cell {
-        private final Cell delegate;
-        private final String name;
-        public DelegateCell(Cell delegate, String name) {
-            this.delegate = delegate;
-            this.name = name;
-        }
-
-        @Override
-        public int getValueOffset() {
-            return delegate.getValueOffset();
-        }
-
-        @Override
-        public int getValueLength() {
-            return delegate.getValueLength();
-        }
-
-        @Override
-        public byte[] getValueArray() {
-            return delegate.getValueArray();
-        }
-
-        @Override
-        public byte[] getValue() {
-            return delegate.getValue();
-        }
-
-        @Override
-        public byte getTypeByte() {
-            return delegate.getTypeByte();
-        }
-
-        @Override
-        public long getTimestamp() {
-            return delegate.getTimestamp();
-        }
-
-        @Override
-        public int getTagsOffset() {
-            return delegate.getTagsOffset();
-        }
-
-        @Override
-        public byte[] getTagsArray() {
-            return delegate.getTagsArray();
-        }
-
-        @Override
-        public int getRowOffset() {
-            return delegate.getRowOffset();
-        }
-
-        @Override
-        public short getRowLength() {
-            return delegate.getRowLength();
-        }
-
-        @Override
-        public byte[] getRowArray() {
-            return delegate.getRowArray();
-        }
-
-        @Override
-        public byte[] getRow() {
-            return delegate.getRow();
-        }
-
-        @Override
-        public int getQualifierOffset() {
-            return delegate.getQualifierOffset();
-        }
-
-        @Override
-        public int getQualifierLength() {
-            return delegate.getQualifierLength();
-        }
-
-        @Override
-        public byte[] getQualifierArray() {
-            return delegate.getQualifierArray();
-        }
-
-        @Override
-        public byte[] getQualifier() {
-            return delegate.getQualifier();
-        }
-
-        @Override
-        public long getMvccVersion() {
-            return delegate.getMvccVersion();
-        }
-
-        @Override
-        public int getFamilyOffset() {
-            return delegate.getFamilyOffset();
-        }
-
-        @Override
-        public byte getFamilyLength() {
-            return delegate.getFamilyLength();
-        }
-
-        @Override
-        public byte[] getFamilyArray() {
-            return delegate.getFamilyArray();
-        }
-
-        @Override
-        public byte[] getFamily() {
-            return delegate.getFamily();
-        }
-        
-        @Override
-        public String toString() {
-            return name;
-        }
-
-        @Override
-        public long getSequenceId() {
-            return delegate.getSequenceId();
-        }
-
-        @Override
-        public int getTagsLength() {
-            return delegate.getTagsLength();
-        }
-
-    }
-    
 }
