@@ -38,6 +38,9 @@ import java.io.File;
 import java.io.IOException;
 import java.math.BigDecimal;
 import java.net.ServerSocket;
+import java.nio.file.Files;
+import java.nio.file.Path;
+import java.nio.file.Paths;
 import java.sql.Connection;
 import java.sql.Date;
 import java.sql.DriverManager;
@@ -808,14 +811,23 @@ public class TestUtil {
     public static void majorCompact(HBaseTestingUtility utility, TableName table)
         throws IOException, InterruptedException {
         long compactionRequestedSCN = EnvironmentEdgeManager.currentTimeMillis();
-        Admin admin = utility.getHBaseAdmin();
+        Admin admin = utility.getAdmin();
         admin.majorCompact(table);
         long lastCompactionTimestamp;
         CompactionState state = null;
-        while ((lastCompactionTimestamp = admin.getLastMajorCompactionTimestamp(table))
-            < compactionRequestedSCN
-            || (state = admin.getCompactionState(table)).equals(CompactionState.MAJOR)
-            || admin.getCompactionState(table).equals(CompactionState.MAJOR_AND_MINOR)){
+        CompactionState previousState = null;
+        while ((state = admin.getCompactionState(table)).equals(CompactionState.MAJOR)
+                || state.equals(CompactionState.MAJOR_AND_MINOR)
+                || (lastCompactionTimestamp =
+                        admin.getLastMajorCompactionTimestamp(table)) < compactionRequestedSCN) {
+            // In HBase 2.5 getLastMajorCompactionTimestamp doesn't seem to get updated when the
+            // clock is stopped, so check for the state going to NONE instead
+            if (state.equals(CompactionState.NONE) && (previousState != null
+                    && previousState.equals(CompactionState.MAJOR_AND_MINOR)
+                    || previousState.equals(CompactionState.MAJOR))) {
+                break;
+            }
+            previousState = state;
             Thread.sleep(100);
         }
     }
@@ -1413,6 +1425,10 @@ public class TestUtil {
         }
     }
 
-
+    public static Path createTempDirectory() throws IOException {
+        // We cannot use java.nio.file.Files.createTempDirectory(null),
+        // because that caches the value of "java.io.tmpdir" on class load.
+        return Files.createTempDirectory(Paths.get(System.getProperty("java.io.tmpdir")), null);
+    }
 
 }
