@@ -17,10 +17,7 @@
  */
 package org.apache.phoenix.compat.hbase.coprocessor;
 
-import org.apache.hadoop.hbase.coprocessor.ObserverContext;
-import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
 import org.apache.hadoop.hbase.coprocessor.RegionObserver;
-import org.apache.hadoop.hbase.wal.WALEdit;
 import org.apache.hadoop.hbase.wal.WALKey;
 
 import java.util.HashMap;
@@ -28,21 +25,16 @@ import java.util.Map;
 
 public class CompatIndexRegionObserver implements RegionObserver {
 
-    public void preWALAppend(ObserverContext<RegionCoprocessorEnvironment> c, WALKey key,
-                             WALEdit edit) {
-        //no-op implementation for HBase 2.1 and 2.2 that doesn't support this co-proc hook.
-    }
-
     public static void appendToWALKey(WALKey key, String attrKey, byte[] attrValue) {
-        //no-op for HBase 2.1 and 2.2 because we don't have WALKey.addExtendedAttribute(String,
-        // byte[])
+        key.addExtendedAttribute(attrKey, attrValue);
     }
 
     public static byte[] getAttributeValueFromWALKey(WALKey key, String attrKey) {
-        return null;
+        return key.getExtendedAttribute(attrKey);
     }
 
     public static Map<String, byte[]> getAttributeValuesFromWALKey(WALKey key) {
-        return new HashMap<String, byte[]>();
+        return new HashMap<String, byte[]>(key.getExtendedAttributes());
     }
+
 }
